@@ -49,8 +49,10 @@ PATTERN=
 for I in \
   action_grid_bar.cpp \
   boolean_tool.cpp \
+  color_wheel_widget.cpp \
   combined_symbol.cpp \
   configure_grid_dialog.cpp \
+  course_file_format.cpp \
   crs_param_widgets.cpp \
   crs_template.cpp \
   crs_template_implementation.cpp \
@@ -63,13 +65,17 @@ for I in \
   georeferencing_dialog.cpp \
   georeferencing_t.cpp \
   icon_engine \
+  iof_course_export \
   key_button_bar.cpp \
+  key_value_container \
+  kml_course_export \
   line_symbol.cpp \
   main.cpp \
   /map.cpp \
   map_coord.cpp \
   map_editor.cpp \
   map_find_feature.cpp \
+  map_printer \
   map_widget.cpp \
   mapper_proxystyle.cpp \
   /object.cpp \
@@ -85,6 +91,8 @@ for I in \
   renderable_implementation.cpp \
   rotate_map_dialog.cpp \
   settings_dialog.cpp \
+  simple_course_dialog.cpp \
+  simple_course_export.cpp \
   stretch_map_dialog.cpp \
   style_t.cpp \
   /symbol.cpp \
