@@ -11,4 +11,4 @@ QT_TRANSLATE_NOOP("OpenOrienteering", "Orienteering map");
 QT_TRANSLATE_NOOP("OpenOrienteering", "Software for drawing orienteering maps");
 
 //: For the moment, we use this existing translation instead of the previous one.
-QT_TRANSLATE_NOOP("AboutDialog", "A free software for drawing orienteering maps");
+QT_TRANSLATE_NOOP("OpenOrienteering::AboutDialog", "A free software for drawing orienteering maps");
