@@ -1,5 +1,5 @@
 /*
- *    Copyright 2012-2020 Kai Pastor
+ *    Copyright 2012-2021 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -52,6 +52,10 @@
 #include "fileformats/xml_file_format.h"
 #include "util/xml_stream_util.h"
 
+#ifdef MAPPER_USE_GDAL
+#  include "gdal/gdal_manager.h"  // IWYU pragma: keep
+#endif
+
 
 // ### A namespace which collects various string constants of type QLatin1String. ###
 
@@ -214,8 +218,11 @@ namespace
 			if (proj_data.exists())
 			{
 				static auto const location = proj_data.absoluteFilePath().toLocal8Bit();
-				static auto* const data = location.constData();
-				proj_context_set_search_paths(nullptr, 1, &data);
+				static const char* const data[2] = { location.constData(), nullptr };
+				proj_context_set_search_paths(nullptr, 1, data);
+#if defined(MAPPER_USE_GDAL)// && !defined(QT_TESTLIB_LIB)
+				GdalManager::setProjSearchPaths(data);
+#endif
 			}
 #endif  // ACCEPT_USE_OF_DEPRECATED_PROJ_API_H
 		}
@@ -282,12 +289,7 @@ ProjTransform& ProjTransform::operator=(ProjTransform&& other) noexcept
 // static
 ProjTransform ProjTransform::crs(const QString& crs_spec)
 {
-	ProjTransform result;
-	auto crs_spec_latin1 = crs_spec.toLatin1();
-	if (!crs_spec_latin1.contains("+no_defs"))
-		crs_spec_latin1.append(" +no_defs");
-	result.pj = pj_init_plus(crs_spec_latin1);
-	return result;
+	return ProjTransform(crs_spec);
 }
 
 bool ProjTransform::isValid() const noexcept
@@ -304,10 +306,12 @@ QPointF ProjTransform::forward(const LatLon& lat_lon, bool* ok) const
 {
 	static auto const geographic_crs = ProjTransform(Georeferencing::geographic_crs_spec);
 	
-	double easting = qDegreesToRadians(lat_lon.longitude()), northing = qDegreesToRadians(lat_lon.latitude());
+	auto point = isGeographic()
+	             ? QPointF{lat_lon.longitude(), lat_lon.latitude()}
+	             : QPointF{qDegreesToRadians(lat_lon.longitude()), qDegreesToRadians(lat_lon.latitude())};
 	if (geographic_crs.isValid())
 	{
-		auto ret = pj_transform(geographic_crs.pj, pj, 1, 1, &easting, &northing, nullptr);
+		auto ret = pj_transform(geographic_crs.pj, pj, 1, 1, &point.rx(), &point.ry(), nullptr);
 		if (ok)
 			*ok = (ret == 0);
 	}
@@ -315,7 +319,7 @@ QPointF ProjTransform::forward(const LatLon& lat_lon, bool* ok) const
 	{
 		*ok = false;
 	}
-	return {easting, northing};
+	return point;
 }
 
 LatLon ProjTransform::inverse(const QPointF& projected_coords, bool* ok) const
@@ -333,7 +337,7 @@ LatLon ProjTransform::inverse(const QPointF& projected_coords, bool* ok) const
 	{
 		*ok = false;
 	}
-	return LatLon::fromRadiant(northing, easting);
+	return isGeographic() ? LatLon{northing, easting} : LatLon::fromRadiant(northing, easting);
 }
 
 QString ProjTransform::errorText() const
@@ -344,6 +348,20 @@ QString ProjTransform::errorText() const
 
 #else
 
+namespace {
+
+QByteArray withTypeCrs(QByteArray crs_spec_utf8)
+{
+	if ((crs_spec_utf8.startsWith("+proj=") || crs_spec_utf8.startsWith("+init="))
+	    && !crs_spec_utf8.contains("+type=crs"))
+	{
+		crs_spec_utf8.append(" +type=crs");
+	}
+	return crs_spec_utf8;
+}
+
+}
+
 ProjTransform::ProjTransform(ProjTransformData* pj) noexcept
 : pj{pj}
 {}
@@ -358,12 +376,14 @@ ProjTransform::ProjTransform(const QString& crs_spec)
 	if (crs_spec.isEmpty())
 		return;
 	
-	auto spec_latin1 = crs_spec.toLatin1();
+	static auto const geographic_crs_spec_utf8 = Georeferencing::geographic_crs_spec.toUtf8();
+	
+	auto crs_spec_utf8 = crs_spec.toUtf8();
 #ifdef PROJ_ISSUE_1573
 	// Cf. https://github.com/OSGeo/PROJ/pull/1573
-	spec_latin1.replace("+datum=potsdam", "+ellps=bessel +nadgrids=@BETA2007.gsb");
+	crs_spec_utf8.replace("+datum=potsdam", "+ellps=bessel +nadgrids=@BETA2007.gsb");
 #endif
-	pj = proj_create_crs_to_crs(PJ_DEFAULT_CTX, Georeferencing::geographic_crs_spec.toLatin1(), spec_latin1, nullptr);
+	pj = proj_create_crs_to_crs(PJ_DEFAULT_CTX, geographic_crs_spec_utf8, crs_spec_utf8, nullptr);
 	if (pj)
 		operator=({proj_normalize_for_visualization(PJ_DEFAULT_CTX, pj)});
 }
@@ -384,7 +404,7 @@ ProjTransform& ProjTransform::operator=(ProjTransform&& other) noexcept
 ProjTransform ProjTransform::crs(const QString& crs_spec)
 {
 	ProjTransform result;
-	auto crs_spec_utf8 = crs_spec.toUtf8();
+	auto crs_spec_utf8 = withTypeCrs(crs_spec.toUtf8().trimmed());
 #ifdef PROJ_ISSUE_1573
 	// Cf. https://github.com/OSGeo/PROJ/pull/1573
 	crs_spec_utf8.replace("+datum=potsdam", "+ellps=bessel +nadgrids=@BETA2007.gsb");
@@ -400,10 +420,17 @@ bool ProjTransform::isValid() const noexcept
 
 bool ProjTransform::isGeographic() const
 {
-	if (!isValid())
-		return false;
+	auto type = pj ? proj_get_type(pj) : PJ_TYPE_UNKNOWN;
+	if (type == PJ_TYPE_BOUND_CRS)
+	{
+		// "Coordinates referring to a BoundCRS are expressed into its source/base CRS."
+		// (https://proj.org/development/reference/cpp/crs.html)
+		auto* base_crs = proj_get_source_crs(nullptr, pj);
+		type = proj_get_type(base_crs);
+		proj_destroy(base_crs);
+	}
 	
-	switch (proj_get_type(pj))
+	switch (type)
 	{
 	case PJ_TYPE_GEOGRAPHIC_CRS:
 	case PJ_TYPE_GEOGRAPHIC_2D_CRS:
@@ -412,7 +439,6 @@ bool ProjTransform::isGeographic() const
 	default:
 		return false;
 	}
-
 }
 
 QPointF ProjTransform::forward(const LatLon& lat_lon, bool* ok) const
@@ -529,7 +555,7 @@ Georeferencing& Georeferencing::operator=(const Georeferencing& other)
 
 bool Georeferencing::isGeographic() const
 {
-	return ProjTransform::crs(getProjectedCRSSpec()).isGeographic();
+	return getState() == Geospatial && ProjTransform::crs(getProjectedCRSSpec()).isGeographic();
 }
 
 
@@ -663,10 +689,7 @@ void Georeferencing::load(QXmlStreamReader& xml, bool load_scale_only)
 	if (!projected_crs_spec.isEmpty())
 	{
 		proj_transform = {projected_crs_spec};
-		if (proj_transform.isValid())
-		{
-			state = Normal;
-		}
+		state = proj_transform.isValid() ? Geospatial : BrokenGeospatial;
 		updateGridCompensation();
 		if (!georef_element.hasAttribute(literal::auxiliary_scale_factor))
 		{
@@ -733,7 +756,7 @@ void Georeferencing::save(QXmlStreamWriter& xml) const
 		}
 	}
 	
-	if (state == Normal)
+	if (getState() == Geospatial)
 	{
 		XmlElementWriter crs_element(xml, literal::geographic_crs);
 		crs_element.writeAttribute(literal::id, literal::geographic_coordinates);
@@ -758,14 +781,14 @@ void Georeferencing::save(QXmlStreamWriter& xml) const
 }
 
 
-void Georeferencing::setState(Georeferencing::State value)
+void Georeferencing::setState(Georeferencing::State const value)
 {
-	if (state != value)
+	if (getState() != value)
 	{
 		state = value;
 		updateTransformation();
 		
-		if (state != Normal)
+		if (value == Local)
 		{
 			setProjectedCRS(QStringLiteral("Local"), {});
 		}
@@ -857,20 +880,18 @@ void Georeferencing::setMapRefPoint(const MapCoord& point)
 
 void Georeferencing::setProjectedRefPoint(const QPointF& point, bool update_grivation, bool update_scale_factor)
 {
-	if (projected_ref_point != point || state == Normal)
+	if (projected_ref_point != point || getState() == Geospatial)
 	{
 		projected_ref_point = point;
 		bool ok = {};
 		LatLon new_geo_ref_point;
 		
-		switch (state)
+		switch (getState())
 		{
-		default:
-			qWarning("Undefined georeferencing state");
-			Q_FALLTHROUGH();
 		case Local:
+		case BrokenGeospatial:
 			break;
-		case Normal:
+		case Geospatial:
 			new_geo_ref_point = toGeographicCoords(point, &ok);
 			if (ok && new_geo_ref_point != geographic_ref_point)
 			{
@@ -915,7 +936,7 @@ void Georeferencing::updateGridCompensation()
 	convergence = 0.0;
 	grid_scale_factor = 1.0;
 
-	if (state != Normal || !isValid())
+	if (getState() != Geospatial)
 		return;
 
 	const double delta = 1000.0; // meters
@@ -980,11 +1001,11 @@ void Georeferencing::updateGridCompensation()
 void Georeferencing::setGeographicRefPoint(LatLon lat_lon, bool update_grivation, bool update_scale_factor)
 {
 	bool geo_ref_point_changed = geographic_ref_point != lat_lon;
-	if (geo_ref_point_changed || state == Normal)
+	if (geo_ref_point_changed || getState() == Geospatial)
 	{
 		geographic_ref_point = lat_lon;
-		if (state != Normal)
-			setState(Normal);
+		if (getState() == Local)
+			setState(BrokenGeospatial);
 		
 		bool ok = {};
 		QPointF new_projected_ref = toProjectedCoords(lat_lon, &ok);
@@ -1069,7 +1090,7 @@ const QTransform& Georeferencing::projectedToMap() const
 bool Georeferencing::setProjectedCRS(const QString& id, QString spec, std::vector<QString> params)
 {
 	// Default return value if no change is necessary
-	bool ok = (state == Normal || projected_crs_spec.isEmpty());
+	bool ok = (getState() == Geospatial || projected_crs_spec.isEmpty());
 	
 	for (const auto& substitution : spec_substitutions)
 	{
@@ -1093,17 +1114,21 @@ bool Georeferencing::setProjectedCRS(const QString& id, QString spec, std::vecto
 		{
 			projected_crs_parameters.clear();
 			proj_transform = {};
-			ok = (state != Normal);
+			ok = (getState() == Local);
+			if (!ok)
+				setState(BrokenGeospatial);
 		}
 		else
 		{
 			projected_crs_parameters.swap(params); // params was passed by value!
 			proj_transform = {projected_crs_spec};
 			ok = proj_transform.isValid();
-			if (ok && state != Normal)
-				setState(Normal);
+			if (ok)
+				setState(Geospatial);
+			else
+				setState(BrokenGeospatial);
 		}
-		if (isValid() && !isLocal())
+		if (getState() == Geospatial)
 			updateGridCompensation();
 		
 		emit projectionChanged();
@@ -1166,10 +1191,10 @@ MapCoordF Georeferencing::toMapCoordF(const Georeferencing* other, const MapCoor
 		return map_coords;
 	}
 	
-	if (isLocal() || other->isLocal())
+	if (getState() != Geospatial || other->getState() != Geospatial)
 	{
 		if (ok)
-			*ok = true;
+			*ok = getState() != BrokenGeospatial && other->getState() != BrokenGeospatial;
 		return toMapCoordF(other->toProjectedCoords(map_coords));
 	}
 	
@@ -1216,6 +1241,18 @@ QString Georeferencing::degToDMS(double val)
 
 QDebug operator<<(QDebug dbg, const Georeferencing &georef)
 {
+	auto state = [](auto state) -> const char* {
+		switch (state)
+		{
+		case Georeferencing::Local:
+			return "local";
+		case Georeferencing::BrokenGeospatial:
+			return "broken";
+		case Georeferencing::Geospatial:
+			return "geospatial";
+		}
+		return "unknown";
+	};
 	dbg.nospace() 
 	  << "Georeferencing(1:" << georef.scale_denominator
 	  << " " << georef.combined_scale_factor
@@ -1223,12 +1260,9 @@ QDebug operator<<(QDebug dbg, const Georeferencing &georef)
 	  << " " << georef.grivation
 	  << "deg, " << georef.projected_crs_id
 	  << " (" << georef.projected_crs_spec
-	  << ") " << QString::number(georef.projected_ref_point.x(), 'f', 8) << "," << QString::number(georef.projected_ref_point.y(), 'f', 8);
-	if (georef.isLocal())
-		dbg.nospace() << ", local)";
-	else
-		dbg.nospace() << ", geographic)";
-	
+	  << ") " << QString::number(georef.projected_ref_point.x(), 'f', 8) << "," << QString::number(georef.projected_ref_point.y(), 'f', 8)
+	  << ", " << state(georef.getState())
+	  << ")";
 	return dbg.space();
 }
 
