@@ -1,6 +1,6 @@
 /*
  *    Copyright 2016 Mitchell Krome
- *    Copyright 2017 Kai Pastor
+ *    Copyright 2017-2020 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -30,6 +30,7 @@
 
 namespace OpenOrienteering {
 
+class Map;
 class Object;
 class Symbol;
 
@@ -55,6 +56,7 @@ public:
 		// Operators 1 .. 15 operate on other queries
 		OperatorAnd      = 1,  ///< And-chains two object queries
 		OperatorOr       = 2,  ///< Or-chains two object queries
+		OperatorNot      = 3,  ///< Negation of the sub-query
 		
 		// Operators 16 .. 18 operate on object tags and other strings
 		OperatorIs       = 16, ///< Tests an existing tag for equality with the given value (case-sensitive)
@@ -135,6 +137,12 @@ public:
 	ObjectQuery(const Symbol* symbol) noexcept;
 	
 	
+	/**
+	 * Returns a query which is the negation of the sub-query.
+	 */
+	static ObjectQuery negation(ObjectQuery query) noexcept;
+	
+	
 	/**
 	 * Returns the underlying operator.
 	 */
@@ -219,11 +227,30 @@ bool operator!=(const ObjectQuery::StringOperands& lhs, const ObjectQuery::Strin
 /**
  * Utility to construct object queries from text.
  * 
- * The text shall be in the formal language generate by ObjectQuery::toString().
+ * The text shall be in the formal language generated by ObjectQuery::toString():
+ * 
+ * <ObjectQuery>      ::=  <AndExpression>  |  <ObjectQuery> 'OR' <AndExpression>
+ * <AndExpression>    ::=  <BoolExpression>  |  <AndExpression> 'AND' <BoolExpression>
+ * <BoolExpression>   ::=  <ParenExpression>  |  <SymbolTerm>  |  <TestTerm>  |  'NOT' <BoolExpression>
+ * <ParenExpression>  ::=  '(' <ObjectQuery> ')'
+ * <SymbolTerm>       ::=  'SYMBOL' <Literal>
+ * <TestTerm>         ::=  <IsTerm> | <IsNotTerm> | <ContainsTerm> | <SearchTerm>
+ * <IsTerm>           ::=  <Literal> '=' <Literal>
+ * <IsNotTerm>        ::=  <Literal> '!=' <Literal>
+ * <ContainsTerm>     ::=  <Literal> '~=' <Literal>
+ * <SearchTerm>       ::=  <Literal>
+ * <Literal>          ::=  <Word> | '"' <String> '"'
+ * <Word>             ::=  ...
+ * <String>           ::=  ...
  */
 class ObjectQueryParser
 {
 public:
+	/**
+	 * Sets the map for looking up symbols.
+	 */
+	void setMap(const Map* map);
+	
 	/**
 	 * Returns an ObjectQuery for the given text.
 	 * 
@@ -244,8 +271,10 @@ public:
 		TokenString,
 		TokenWord,
 		TokenTextOperator,
+		TokenSymbol,
 		TokenOr,
 		TokenAnd,
+		TokenNot,
 		TokenLeftParen,
 		TokenRightParen,
 	};
@@ -255,6 +284,9 @@ private:
 	
 	QString tokenAsString() const;
 	
+	const Symbol* findSymbol(const QString& key) const;
+	
+	const Map* map = nullptr;
 	QStringRef input;
 	QStringRef token_text;
 	TokenType token;
