@@ -58,7 +58,6 @@ class CombinedSymbol : public Symbol
 {
 friend class CombinedSymbolSettings;
 friend class PointSymbolEditorWidget;
-friend class OCAD8FileImport;
 public:
 	CombinedSymbol();
 	~CombinedSymbol() override;
@@ -113,6 +112,8 @@ public:
 	inline bool isPartPrivate(int i) const {return private_parts[i];}
 	inline void setPartPrivate(int i, bool set_private) {private_parts[i] = set_private;}
 	
+	bool hasRotatableFillPattern() const override;
+	
 	SymbolPropertiesWidget* createPropertiesWidget(SymbolSettingDialog* dialog) override;
 	
 protected:
