@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013 Thomas Schöps
- *    Copyright 2012-2017 Kai Pastor
+ *    Copyright 2012-2019 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -29,7 +29,6 @@
 #include <QtGlobal>
 #include <QCoreApplication>
 #include <QFont>
-#include <QIODevice>
 #include <QLatin1String>
 #include <QPointF>
 #include <QRectF>
@@ -57,67 +56,78 @@
 namespace OpenOrienteering {
 
 TextSymbol::TextSymbol()
-: Symbol(Symbol::Text)
-, metrics(QFont())
+: Symbol { Symbol::Text }
+, qfont {}
+, metrics { qfont }
+, font_family { QStringLiteral("Arial") }
+, icon_text { }
+, color { nullptr }
+, framing_color { nullptr }
+, line_below_color { nullptr }
+, line_spacing { 1 }
+, character_spacing { 0 }
+, font_size { 4 * 1000 }
+, paragraph_spacing { 0 }
+, framing_mode { LineFraming }
+, framing_line_half_width { 200 }
+, framing_shadow_x_offset { 200 }
+, framing_shadow_y_offset { 200 }
+, line_below_width { 0 }
+, line_below_distance { 0 }
+, bold { false }
+, italic { false }
+, underline { false }
+, kerning { true }
+, framing { false }
+, line_below { false }
 {
-	color = nullptr;
-	font_family = QString::fromLatin1("Arial");
-	font_size = 4 * 1000;
-	bold = false;
-	italic = false;
-	underline = false;
-	line_spacing = 1;
-	paragraph_spacing = 0;
-	character_spacing = 0;
-	kerning = true;
-	icon_text = QString{};
-	framing = false;
-	framing_color = nullptr;
-	framing_mode = LineFraming;
-	framing_line_half_width = 200;
-	framing_shadow_x_offset = 200;
-	framing_shadow_y_offset = 200;
-	line_below = false;
-	line_below_color = nullptr;
-	line_below_width = 0;
-	line_below_distance = 0;
+	setRotatable(true);
 	updateQFont();
 }
 
 
+TextSymbol::TextSymbol(const TextSymbol& proto)
+: Symbol { proto }
+, qfont { proto.qfont }
+, metrics { proto.metrics }
+, font_family { proto.font_family }
+, icon_text { proto.icon_text }
+, color { proto.color }
+, framing_color { proto.framing_color }
+, line_below_color { proto.line_below_color }
+, custom_tabs { proto.custom_tabs }
+, tab_interval { proto.tab_interval }
+, line_spacing { proto.line_spacing }
+, character_spacing { proto.character_spacing }
+, font_size { proto.font_size }
+, paragraph_spacing { proto.paragraph_spacing }
+, framing_mode { proto.framing_mode }
+, framing_line_half_width { proto.framing_line_half_width }
+, framing_shadow_x_offset { proto.framing_shadow_x_offset }
+, framing_shadow_y_offset { proto.framing_shadow_y_offset }
+, line_below_width { proto.line_below_width }
+, line_below_distance { proto.line_below_distance }
+, bold { proto.bold }
+, italic { proto.italic }
+, underline { proto.underline }
+, kerning { proto.kerning }
+, framing { proto.framing }
+, line_below { proto.line_below }
+{
+	// nothing else
+}
+
+
 TextSymbol::~TextSymbol() = default;
 
 
-Symbol* TextSymbol::duplicate(const MapColorMap* color_map) const
+TextSymbol* TextSymbol::duplicate() const
 {
-	auto new_text = new TextSymbol();
-	new_text->duplicateImplCommon(this);
-	new_text->color = color_map ? color_map->value(color) : color;
-	new_text->font_family = font_family;
-	new_text->font_size = font_size;
-	new_text->bold = bold;
-	new_text->italic = italic;
-	new_text->underline = underline;
-	new_text->line_spacing = line_spacing;
-	new_text->paragraph_spacing = paragraph_spacing;
-	new_text->character_spacing = character_spacing;
-	new_text->kerning = kerning;
-	new_text->icon_text = icon_text;
-	new_text->framing = framing;
-	new_text->framing_color = color_map ? color_map->value(framing_color) : framing_color;
-	new_text->framing_mode = framing_mode;
-	new_text->framing_line_half_width = framing_line_half_width;
-	new_text->framing_shadow_x_offset = framing_shadow_x_offset;
-	new_text->framing_shadow_y_offset = framing_shadow_y_offset;
-	new_text->line_below = line_below;
-	new_text->line_below_color = color_map ? color_map->value(line_below_color) : line_below_color;
-	new_text->line_below_width = line_below_width;
-	new_text->line_below_distance = line_below_distance;
-	new_text->custom_tabs = custom_tabs;
-	new_text->updateQFont();
-	return new_text;
+	return new TextSymbol(*this);
 }
 
+
+
 void TextSymbol::createRenderables(
         const Object *object,
         const VirtualCoordVector &coords,
@@ -243,7 +253,7 @@ void TextSymbol::createLineBelowRenderables(const Object* object, ObjectRenderab
 	}
 }
 
-void TextSymbol::colorDeleted(const MapColor* c)
+void TextSymbol::colorDeletedEvent(const MapColor* c)
 {
 	auto changes = 0;
 	if (c == color)
@@ -284,6 +294,13 @@ const MapColor* TextSymbol::guessDominantColor() const
 	return c;
 }
 
+void TextSymbol::replaceColors(const MapColorMap& color_map)
+{
+	color = color_map.value(color);
+	framing_color = color_map.value(framing_color);
+	line_below_color = color_map.value(line_below_color);
+}
+
 void TextSymbol::scale(double factor)
 {
 	font_size = qMax(10, qRound(factor * font_size)); // minimum 0.01 mm
@@ -315,61 +332,14 @@ void TextSymbol::updateQFont()
 	tab_interval = 8.0 * metrics.averageCharWidth();
 }
 
-#ifndef NO_NATIVE_FILE_FORMAT
 
-bool TextSymbol::loadImpl(QIODevice* file, int version, Map* map)
-{
-	int temp;
-	file->read((char*)&temp, sizeof(int));
-	color = (temp >= 0) ? map->getColor(temp) : nullptr;
-	loadString(file, font_family);
-	file->read((char*)&font_size, sizeof(int));
-	file->read((char*)&bold, sizeof(bool));
-	file->read((char*)&italic, sizeof(bool));
-	file->read((char*)&underline, sizeof(bool));
-	file->read((char*)&line_spacing, sizeof(float));
-	if (version >= 13)
-		file->read((char*)&paragraph_spacing, sizeof(double));
-	if (version >= 14)
-		file->read((char*)&character_spacing, sizeof(double));
-	if (version >= 12)
-		file->read((char*)&kerning, sizeof(bool));
-	if (version >= 19)
-		loadString(file, icon_text);
-	if (version >= 20)
-	{
-		file->read((char*)&framing, sizeof(bool));
-		file->read((char*)&temp, sizeof(int));
-		framing_color = map->getColor(temp);
-		file->read((char*)&framing_mode, sizeof(int));
-		file->read((char*)&framing_line_half_width, sizeof(int));
-		file->read((char*)&framing_shadow_x_offset, sizeof(int));
-		file->read((char*)&framing_shadow_y_offset, sizeof(int));	
-	}
-	if (version >= 13)
-	{
-		file->read((char*)&line_below, sizeof(bool));
-		file->read((char*)&temp, sizeof(int));
-		line_below_color = (temp >= 0) ? map->getColor(temp) : nullptr;
-		file->read((char*)&line_below_width, sizeof(int));
-		file->read((char*)&line_below_distance, sizeof(int));
-		int num_custom_tabs;
-		file->read((char*)&num_custom_tabs, sizeof(int));
-		custom_tabs.resize(num_custom_tabs);
-		for (int i = 0; i < num_custom_tabs; ++i)
-			file->read((char*)&custom_tabs[i], sizeof(int));
-	}
-	
-	updateQFont();
-	return true;
-}
-
-#endif
 
 void TextSymbol::saveImpl(QXmlStreamWriter& xml, const Map& map) const
 {
 	xml.writeStartElement(QStringLiteral("text_symbol"));
 	xml.writeAttribute(QStringLiteral("icon_text"), icon_text);
+	if (isRotatable())
+		xml.writeAttribute(QString::fromLatin1("rotatable"), QString::fromLatin1("true"));
 	
 	xml.writeStartElement(QStringLiteral("font"));
 	xml.writeAttribute(QStringLiteral("family"), font_family);
@@ -424,14 +394,16 @@ void TextSymbol::saveImpl(QXmlStreamWriter& xml, const Map& map) const
 	xml.writeEndElement(/*text_symbol*/);
 }
 
-bool TextSymbol::loadImpl(QXmlStreamReader& xml, const Map& map, SymbolDictionary& symbol_dict)
+bool TextSymbol::loadImpl(QXmlStreamReader& xml, const Map& map, SymbolDictionary& /*symbol_dict*/, int version)
 {
-	Q_UNUSED(symbol_dict);
-	
 	if (xml.name() != QLatin1String("text_symbol"))
 		return false;
 	
 	icon_text = xml.attributes().value(QLatin1String("icon_text")).toString();
+	if (xml.attributes().hasAttribute(QLatin1String("rotatable")))
+		setRotatable(xml.attributes().value(QLatin1String("rotatable")) == QLatin1String("true"));
+	else
+		setRotatable(version < 9); // always rotatable before version 9
 	framing = false;
 	line_below = false;
 	custom_tabs.clear();
