@@ -19,8 +19,11 @@
 
 #include "virtual_coord_vector.h"
 
+#include "core/map_coord.h"
 
 
+namespace OpenOrienteering {
+
 //### VirtualCoordVector ###
 
 MapCoordF VirtualCoordVector::fromMapCoordF(size_type index) const
@@ -34,3 +37,4 @@ MapCoordF VirtualCoordVector::fromMapCoord(size_type index) const
 }
 
 
+}  // namespace OpenOrienteering
