@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013 Pete Curtis
- *    Copyright 2018 Kai Pastor
+ *    Copyright 2018-2020 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -70,12 +70,37 @@ public:
 	 */
 	const char* what() const noexcept override;
 	
+	
+	/**
+	 * Returns an exception object representing an internal error
+	 * in the given function.
+	 * 
+	 * This is a helper function used by the FILEFORMAT_ASSERT macro.
+	 */
+	static FileFormatException internalError(const char* function_info);
+	
+	
 private:
 	QString const msg;
 	QByteArray const msg_c;
 };
 
 
+/**
+ * Checks if the condition is true, and raises an exception otherwise.
+ * 
+ * This macro is to be used by importer and exporter implementations instead
+ * of plain assert or Q_ASSERT: In most cases, program consistency is not
+ * affected by internal errors of importers or exporters, and so there is no
+ * reason to abort the program (debug builds) or to let it run into a crash
+ * (release build). However, on hot paths, evaluating the condition must not
+ * be expensive.
+ */
+#define FILEFORMAT_ASSERT(condition) \
+	if (Q_UNLIKELY(!(condition))) throw FileFormatException::internalError(Q_FUNC_INFO);
+
+
+
 /** Describes a file format understood by this application. Each file format has an ID
  *  (an internal, non-translated string); a description (translated); a file extension
  *  (non-translated); and methods to indicate their support for import or export. Formats
@@ -113,6 +138,7 @@ public:
 	{
 		MapFile     = 0x01,
 		OgrFile     = 0x02,     ///< Geospatial vector data supported by OGR
+		SimpleCourseFile = 0x04,///< Course interchange formats
 		
 		AllFiles    = MapFile,  ///< All types which can be handled by an editor.
 		
@@ -271,6 +297,15 @@ public:
 	virtual ImportSupportAssumption understands(const char* buffer, int size) const;
 	
 	
+	/**
+	 * Returns a filepath which ends with one of the formats extensions.
+	 * 
+	 * If the filepath does not already end with one the extensions,
+	 * this function appends the primary extension (separated by dot).
+	 */
+	QString fixupExtension(QString filepath) const;
+	
+	
 	/**
 	 * Creates an Importer that will read a map file from the given stream.
 	 * 
@@ -290,7 +325,7 @@ private:
 	const char* format_id;
 	QString format_description;
 	QStringList file_extensions;
-	QString format_filter;
+	mutable QString format_filter;
 	Features format_features;
 };
 
@@ -361,12 +396,6 @@ const QStringList& FileFormat::fileExtensions() const
 	return file_extensions;
 }
 
-inline
-const QString& FileFormat::filter() const
-{
-	return format_filter;
-}
-
 
 }  // namespace OpenOrienteering
 
