@@ -145,7 +145,7 @@ void Importer::importFailed()
 void Importer::validate()
 {
 	auto const& georef = map->getGeoreferencing();
-	if (georef.isValid() && !georef.isLocal())
+	if (georef.getState() == Georeferencing::Geospatial)
 	{
 		auto const expected = georef.getProjectedRefPoint();
 		auto const actual = georef.toProjectedCoords(georef.getGeographicRefPoint());
@@ -248,7 +248,7 @@ void Importer::validate()
 		if (!error_string.isEmpty())
 		{
 			addWarning(tr("Warnings when loading template '%1':\n%2")
-			           .arg(temp->getTemplateFilename(), temp->errorString()));
+			           .arg(temp->getTemplateFilename(), error_string));
 		}
 	}
 	
@@ -291,26 +291,29 @@ bool Exporter::doExport()
 		}
 		if (!device_->isOpen() && !device_->open(QIODevice::WriteOnly))
 		{
-			addWarning(tr("Cannot save file\n%1:\n%2").arg(path, device_->errorString()));
+			addWarning(device_->errorString());
 			return false;
 		}
 	}
 	
+	auto success = true;
+	// Save the map
 	try
 	{
 		if (!exportImplementation())
 		{
 			Q_ASSERT(!warnings().empty());
-			return false;
+			success = false;
 		}
-		if (managed_file && !managed_file->commit())
+		if (success && managed_file && !managed_file->commit())
 		{
-			addWarning(tr("Cannot save file\n%1:\n%2").arg(path, managed_file->errorString()));
-			return false;
+			addWarning(managed_file->errorString());
+			success = false;
 		}
 #ifdef Q_OS_ANDROID
 		// Make the MediaScanner aware of the *updated* file.
-		if (auto* file_device = qobject_cast<QFileDevice*>(device_))
+		auto* file_device = qobject_cast<QFileDevice*>(device_);
+		if (success && file_device)
 		{
 			const auto file_info = QFileInfo(file_device->fileName());
 			Android::mediaScannerScanFile(file_info.absolutePath());
@@ -319,11 +322,31 @@ bool Exporter::doExport()
 	}
 	catch (std::exception &e)
 	{
-		addWarning(tr("Cannot save file\n%1:\n%2").arg(path, QString::fromLocal8Bit(e.what())));
-		return false;
+		addWarning(QString::fromLocal8Bit(e.what()));
+		success = false;
 	}
 	
-	return true;
+	// Save modified templates
+	for (auto i = 0; i < map->getNumTemplates(); ++i)
+	{
+		auto const* temp = map->getTemplate(i);
+		auto const filename = temp->getTemplateFilename();
+		try
+		{
+			if (temp->hasUnsavedChanges() && !temp->saveTemplateFile())
+			{
+				addWarning(tr("Cannot save file\n%1:\n%2").arg(filename, temp->errorString()));
+				success = false;
+			}
+		}
+		catch (std::exception &e)
+		{
+			addWarning(tr("Cannot save file\n%1:\n%2").arg(filename, QString::fromLocal8Bit(e.what())));
+			success = false;
+		}
+	}
+	
+	return success;
 }
 
 
