@@ -1,5 +1,5 @@
 /*
- *    Copyright 2016-2019 Kai Pastor
+ *    Copyright 2016-2020 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -50,8 +50,13 @@ GdalSettingsPage::GdalSettingsPage(QWidget* parent)
 {
 	auto form_layout = new QFormLayout();
 	
+	Q_UNUSED(QT_TR_NOOP("Import Options"))  // \todo 1.0 Switch to new translation
 	form_layout->addRow(Util::Headline::create(tr("Import with GDAL/OGR:")));
 	
+	clip_layers = new QCheckBox(tr("Clip layers"));
+	form_layout->addRow(clip_layers);
+	
+	Q_UNUSED(QT_TR_NOOP("Use GDAL for GPX"))  // \todo 1.0 Switch to new translation
 	import_gpx = new QCheckBox(tr("GPX"));
 	form_layout->addRow(import_gpx);
 	
@@ -99,6 +104,7 @@ GdalSettingsPage::~GdalSettingsPage() = default;
 
 QString GdalSettingsPage::title() const
 {
+	Q_UNUSED(QT_TR_NOOP("GDAL"))  // \todo 1.0 Switch to new translation
 	return tr("GDAL/OGR");
 }
 
@@ -115,6 +121,7 @@ void GdalSettingsPage::apply()
 	FileFormats.registerFormat(format);
 
 	manager.setExportOptionEnabled(GdalManager::OneLayerPerSymbol, export_one_layer_per_symbol->isChecked());
+	manager.setImportOptionEnabled(GdalManager::ClipLayers, clip_layers->isChecked());
 	
 	const auto old_parameters = manager.parameterKeys();
 	
@@ -149,6 +156,7 @@ void GdalSettingsPage::reset()
 void GdalSettingsPage::updateWidgets()
 {
 	GdalManager manager;
+	clip_layers->setChecked(manager.isImportOptionEnabled(GdalManager::ClipLayers));
 	import_gpx->setChecked(manager.isFormatEnabled(GdalManager::GPX));
 	view_hatch->setChecked(manager.isAreaHatchingEnabled());
 	view_baseline->setChecked(manager.isBaselineViewEnabled());
