@@ -23,12 +23,16 @@
 #include <memory>
 #include <vector>
 
+#include <QtGlobal>
 #include <QObject>
 #include <QString>
 
+#include "templates/template.h"
 #include "templates/template_map.h"
 
 class QByteArray;
+class QPainter;
+class QRectF;
 class QWidget;
 class QXmlStreamReader;
 class QXmlStreamWriter;
@@ -37,6 +41,7 @@ namespace OpenOrienteering {
 
 class Georeferencing;
 class Map;
+class MapView;
 
 
 /**
@@ -67,6 +72,12 @@ public:
 	
 	const char* getTemplateType() const override;
 	
+	
+	LookupResult tryToFindTemplateFile(const QString& map_path) override;
+	
+	bool fileExists() const override;
+	
+	
 	std::unique_ptr<Georeferencing> makeOrthographicGeoreferencing(const QString& path) const;
 	std::unique_ptr<Georeferencing> makeOrthographicGeoreferencing() const;
 	std::unique_ptr<Georeferencing> makeGeoreferencing(const QString& spec) const;
@@ -90,14 +101,26 @@ public:
 	 */
 	bool loadTemplateFileImpl() override;
 	
+private:
+	void loadChildTemplatesAsync(MapView& view);
+	
+public:
 	bool postLoadSetup(QWidget* dialog_parent, bool& out_center_in_view) override;
 	
+	void unloadTemplateFileImpl() override;
+	
 	
 	bool canChangeTemplateGeoreferenced() const override;
 	
 	
+	void drawTemplate(QPainter* painter, const QRectF& clip_rect, double scale, bool on_screen, qreal opacity) const override;
+	
+	QRectF getTemplateExtent() const override;
+	
+	
 	void applySettings();
 	
+	
 protected:
 	void updateView(Map& template_map);
 	
