@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013, 2014 Thomas Schöps
- *    Copyright 2012-2017 Kai Pastor
+ *    Copyright 2012-2020 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -23,6 +23,7 @@
 
 #include "mapper_config.h" // IWYU pragma: keep
 
+#include "fileformats/course_file_format.h"
 #include "fileformats/file_format_registry.h"
 #include "fileformats/xml_file_format.h"
 #include "fileformats/ocd_file_format.h"
@@ -40,9 +41,12 @@ void doStaticInitializations()
 		FileFormats.registerFormat(format.release());
 #endif
 #ifdef MAPPER_USE_GDAL
-	FileFormats.registerFormat(new OgrFileExportFormat());
 	FileFormats.registerFormat(new OgrFileImportFormat());
+	for (auto&& format : OgrFileExportFormat::makeAll())
+		FileFormats.registerFormat(format.release());
 #endif
+	for (auto&& format : CourseFileFormat::makeAll())
+		FileFormats.registerFormat(format.release());
 }
 
 
