@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013, 2014 Thomas Schöps
- *    Copyright 2012-2017 Kai Pastor
+ *    Copyright 2012-2019 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -111,12 +111,14 @@ QString AboutDialog::about()
 	static QStringList developers_list( QStringList()
 	  << QString::fromLatin1("Peter Curtis (2012-2013)")
 	  << QString::fromLatin1("<b>Kai Pastor</b>")
+	  << QString::fromUtf8("<b>Libor Pecháček</b>")
 	  << QString::fromUtf8("Thomas Schöps (2012-2014, %1)")
 	);
 	
 	static QStringList contributors_list( QStringList()
 	  << QString::fromLatin1("Arrizal Amin")
 	  << QString::fromLatin1("Javier Arufe")
+	  << QString::fromLatin1("Jonathan Bakker")
 	  << QString::fromLatin1("Eric Boulet")
 	  << QString::fromLatin1("Jon Cundill")
 	  << QString::fromUtf8("Sławomir Cygler")
@@ -145,6 +147,7 @@ QString AboutDialog::about()
 	  << QString::fromLatin1("Christopher Schive")
 	  << QString::fromLatin1("Arif Suryawan")
 	  << QString::fromLatin1("Jan-Gerard van der Toorn")
+	  << QString::fromLatin1("Scott Turner")
 	  << QString::fromLatin1("Semyon Yakimov")
 	  << QString::fromLatin1("Aivars Zogla")
 	);
@@ -161,7 +164,7 @@ QString AboutDialog::about()
 	  "<p>"
 	  "<em>%3</em><br/>"
 	  "<a href=\"%4\">%4</a></p>"
-	  "<p>Copyright (C) 2018 The OpenOrienteering developers</p>"
+	  "<p>Copyright %2</p>"
 	  "<p>%5</p>"
 	  "<p>%6</p>"
 	  "<p>%7</p>"
@@ -171,8 +174,9 @@ QString AboutDialog::about()
 	).arg(
 	  tr("About %1").arg(APP_NAME), // %0
 	  qApp->applicationDisplayName(),   // %1
+	  QString::fromLatin1(APP_COPYRIGHT),   // %2
 	  tr("A free software for drawing orienteering maps"), // %3
-	  QString::fromLatin1("http://openorienteering.org/apps/mapper/"), // %4
+	  QString::fromLatin1("https://www.openorienteering.org/apps/mapper/"), // %4
 	  tr("This program is free software: you can redistribute it "
 	     "and/or modify it under the terms of the "
 	     "<a %1>GNU General Public License (GPL), version&nbsp;3</a>, "
