@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013, 2014 Thomas Schöps
- *    Copyright 2013-2020 Kai Pastor
+ *    Copyright 2013-2021 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -255,7 +255,19 @@ public:
 	 */
 	bool keyReleaseEventFilter(QKeyEvent* event) override;
 	
+	
+	/**
+	 * Lets the user export the map as vector data file of one of the given types.
+	 */
+	void exportVectorData(int file_types, const QString& format_settings_key);
+	
+	
 public slots:
+	/**
+	 * Lets the user export a PathObject as a simple course.
+	 */
+	void exportSimpleCourse();
+	
 	/**
 	 * Lets the user export the map as geospatial vector data.
 	 */
@@ -686,136 +698,138 @@ private:
 	EditorDockWidget* print_dock_widget;
 	PrintWidget* print_widget;
 	
-	QAction* print_act;
-	QAction* export_image_act;
-	QAction* export_pdf_act;
-	QAction* export_vector_act;
+	QAction* print_act = {};
+	QAction* export_image_act = {};
+	QAction* export_kmz_act = {};
+	QAction* export_simple_course_act = {};
+	QAction* export_pdf_act = {};
+	QAction* export_vector_act = {};
 	
-	QAction* undo_act;
-	QAction* redo_act;
-	QAction* cut_act;
-	QAction* copy_act;
-	QAction* paste_act;
-	QAction* delete_act;
-	QAction* select_all_act;
-	QAction* select_nothing_act;
-	QAction* invert_selection_act;
-	QAction* select_by_current_symbol_act;
+	QAction* undo_act = {};
+	QAction* redo_act = {};
+	QAction* cut_act = {};
+	QAction* copy_act = {};
+	QAction* paste_act = {};
+	QAction* delete_act = {};
+	QAction* select_all_act = {};
+	QAction* select_nothing_act = {};
+	QAction* invert_selection_act = {};
+	QAction* select_by_current_symbol_act = {};
 	std::unique_ptr<MapFindFeature> find_feature;
-	QAction* clear_undo_redo_history_act;
+	QAction* clear_undo_redo_history_act = {};
 	
-	QAction* pan_act;
-	QAction* move_to_gps_pos_act;
-	QAction* follow_position_act;
-	QAction* zoom_in_act;
-	QAction* zoom_out_act;
-	QAction* show_all_act;
-	QAction* fullscreen_act;
-	QAction* custom_zoom_act;
-	QAction* show_grid_act;
-	QAction* configure_grid_act;
-	QAction* hatch_areas_view_act;
-	QAction* baseline_view_act;
-	QAction* hide_all_templates_act;
-	QAction* overprinting_simulation_act;
+	QAction* pan_act = {};
+	QAction* move_to_gps_pos_act = {};
+	QAction* follow_position_act = {};
+	QAction* zoom_in_act = {};
+	QAction* zoom_out_act = {};
+	QAction* show_all_act = {};
+	QAction* fullscreen_act = {};
+	QAction* custom_zoom_act = {};
+	QAction* show_grid_act = {};
+	QAction* configure_grid_act = {};
+	QAction* hatch_areas_view_act = {};
+	QAction* baseline_view_act = {};
+	QAction* hide_all_templates_act = {};
+	QAction* overprinting_simulation_act = {};
 	
-	QAction* map_coordinates_act;
-	QAction* projected_coordinates_act;
-	QAction* geographic_coordinates_act;
-	QAction* geographic_coordinates_dms_act;
+	QAction* map_coordinates_act = {};
+	QAction* projected_coordinates_act = {};
+	QAction* geographic_coordinates_act = {};
+	QAction* geographic_coordinates_dms_act = {};
 	
-	QMenu* toolbars_menu = nullptr;
+	QMenu* toolbars_menu = {};
 	
-	QAction* scale_all_symbols_act;
-	QAction* georeferencing_act;
-	QAction* scale_map_act;
-	QAction* rotate_map_act;
-	QAction* map_notes_act;
-	QAction* symbol_set_id_act;
+	QAction* scale_all_symbols_act = {};
+	QAction* georeferencing_act = {};
+	QAction* scale_map_act = {};
+	QAction* rotate_map_act = {};
+	QAction* map_notes_act = {};
+	QAction* symbol_set_id_act = {};
 	
-	QAction* color_window_act;
+	QAction* color_window_act = {};
 	QPointer<EditorDockWidget> color_dock_widget;
-	QAction* load_symbols_from_act;
-	QAction* load_crt_act;
+	QAction* load_symbols_from_act = {};
+	QAction* load_crt_act = {};
 	
-	QAction* symbol_window_act;
+	QAction* symbol_window_act = {};
 	EditorDockWidget* symbol_dock_widget;
 	SymbolWidget* symbol_widget;
 	
-	QAction* template_window_act;
+	QAction* template_window_act = {};
 	QPointer<QWidget> template_dock_widget;
 	TemplateListWidget* template_list_widget;
-	QAction* open_template_act;
-	QAction* reopen_template_act;
+	QAction* open_template_act = {};
+	QAction* reopen_template_act = {};
 	
-	QAction* tags_window_act;
+	QAction* tags_window_act = {};
 	QPointer<EditorDockWidget> tags_dock_widget;
 	
-	QAction* edit_tool_act;
-	QAction* edit_line_tool_act;
-	QAction* draw_point_act;
-	QAction* draw_path_act;
-	QAction* draw_circle_act;
-	QAction* draw_rectangle_act;
-	QAction* draw_freehand_act;
-	QAction* draw_fill_act;
-	QAction* draw_text_act;
+	QAction* edit_tool_act = {};
+	QAction* edit_line_tool_act = {};
+	QAction* draw_point_act = {};
+	QAction* draw_path_act = {};
+	QAction* draw_circle_act = {};
+	QAction* draw_rectangle_act = {};
+	QAction* draw_freehand_act = {};
+	QAction* draw_fill_act = {};
+	QAction* draw_text_act = {};
 	
-	QAction* duplicate_act;
-	QAction* switch_symbol_act;
-	QAction* fill_border_act;
-	QAction* switch_dashes_act;
-	QAction* connect_paths_act;
-	QAction* cut_tool_act;
-	QMenu* cut_hole_menu;
-	QAction* cut_hole_act;
-	QAction* cut_hole_circle_act;
-	QAction* cut_hole_rectangle_act;
-	QAction* rotate_act;
-	QAction* rotate_pattern_act;
-	QAction* scale_act;
-	QAction* measure_act;
+	QAction* duplicate_act = {};
+	QAction* switch_symbol_act = {};
+	QAction* fill_border_act = {};
+	QAction* switch_dashes_act = {};
+	QAction* connect_paths_act = {};
+	QAction* cut_tool_act = {};
+	QMenu* cut_hole_menu = {};
+	QAction* cut_hole_act = {};
+	QAction* cut_hole_circle_act = {};
+	QAction* cut_hole_rectangle_act = {};
+	QAction* rotate_act = {};
+	QAction* rotate_pattern_act = {};
+	QAction* scale_act = {};
+	QAction* measure_act = {};
 	EditorDockWidget* measure_dock_widget;
-	QAction* boolean_union_act;
-	QAction* boolean_intersection_act;
-	QAction* boolean_difference_act;
-	QAction* boolean_xor_act;
-	QAction* boolean_merge_holes_act;
-	QAction* convert_to_curves_act;
-	QAction* simplify_path_act;
-	QAction* cutout_physical_act;
-	QAction* cutaway_physical_act;
-	QAction* distribute_points_act;
+	QAction* boolean_union_act = {};
+	QAction* boolean_intersection_act = {};
+	QAction* boolean_difference_act = {};
+	QAction* boolean_xor_act = {};
+	QAction* boolean_merge_holes_act = {};
+	QAction* convert_to_curves_act = {};
+	QAction* simplify_path_act = {};
+	QAction* cutout_physical_act = {};
+	QAction* cutaway_physical_act = {};
+	QAction* distribute_points_act = {};
 	
 	std::unique_ptr<PaintOnTemplateFeature> paint_feature;
 	
-	QAction* touch_cursor_action;
-	QAction* gps_display_action;
-	QAction* gps_distance_rings_action;
-	QAction* draw_point_gps_act;
-	QAction* gps_temporary_point_act;
-	QAction* gps_temporary_path_act;
-	QAction* gps_temporary_clear_act;
+	QAction* touch_cursor_action = {};
+	QAction* gps_display_action = {};
+	QAction* gps_distance_rings_action = {};
+	QAction* draw_point_gps_act = {};
+	QAction* gps_temporary_point_act = {};
+	QAction* gps_temporary_path_act = {};
+	QAction* gps_temporary_clear_act = {};
 	GPSTemporaryMarkers* gps_marker_display;
 	GPSDisplay* gps_display;
 	GPSTrackRecorder* gps_track_recorder;
-	QAction* compass_action;
+	QAction* compass_action = {};
 	CompassDisplay* compass_display;
-	QAction* align_map_with_north_act;
+	QAction* align_map_with_north_act = {};
 	QTimer align_map_with_north_timer;
 	
-	QAction* mappart_add_act;
-	QAction* mappart_rename_act;
-	QAction* mappart_remove_act;
-	QAction* mappart_merge_act;
+	QAction* mappart_add_act = {};
+	QAction* mappart_rename_act = {};
+	QAction* mappart_remove_act = {};
+	QAction* mappart_merge_act = {};
 	QMenu* mappart_merge_menu;
 	QMenu* mappart_move_menu;
 	
-	QAction* import_act;
+	QAction* import_act = {};
 	
 	QFrame* statusbar_zoom_frame;
 	QLabel* statusbar_cursorpos_label;
-	QAction* copy_coords_act;
+	QAction* copy_coords_act = {};
 	
 	QToolBar* toolbar_view;
 	QToolBar* toolbar_drawing;
