@@ -104,6 +104,8 @@
 #endif
 
 
+namespace OpenOrienteering {
+
 namespace {
 
 QVariant makeCheckBoxDecorator(QStyle* style, const QSize& size)
@@ -121,25 +123,15 @@ QVariant makeCheckBoxDecorator(QStyle* style, const QSize& size)
 	return pixmap;
 }
 
-/**
- * Returns a new QToolButton with a unified appearance.
- */
-QToolButton* newToolButton(const QIcon& icon, const QString& text)
+/// Local wrapper for Util::ToolButton::create() adding the What's This bit.
+QToolButton* createToolButton(const QIcon& icon, const QString& text)
 {
-	auto* button = new QToolButton();
-	button->setToolButtonStyle(Qt::ToolButtonIconOnly);
-	button->setToolTip(text);
-	button->setIcon(icon);
-	button->setText(text);
-	button->setWhatsThis(OpenOrienteering::Util::makeWhatThis("templates.html#setup"));
-	return button;
+	return Util::ToolButton::create(icon, text, "templates.html#setup");
 }
 
-}
+}  // anonymous namespace
 
 
-namespace OpenOrienteering {
-
 // ### TemplateListWidget ###
 
 // Template grouping implementation is incomplete
@@ -200,6 +192,9 @@ TemplateListWidget::TemplateListWidget(Map& map, MapView& main_view, MapEditorCo
 	// Template grouping is not yet implemented.
 	template_table->hideColumn(TemplateTableModel::groupColumn());
 #endif
+	connect(template_model, &TemplateTableModel::rowsInserted, this, [this](const QModelIndex& /*unused*/, int first) {
+		template_table->selectRow(first);
+	});
 	
 	auto* percentage_delegate = new PercentageDelegate(this, 5);
 	template_table->setItemDelegateForColumn(1, percentage_delegate);
@@ -253,19 +248,19 @@ TemplateListWidget::TemplateListWidget(Map& map, MapView& main_view, MapEditorCo
 	current_action->setDisabled(true);
 #endif
 	
-	auto* new_button = newToolButton(QIcon(QString::fromLatin1(":/images/plus.png")), tr("Add template..."));
+	auto* new_button = createToolButton(QIcon(QString::fromLatin1(":/images/plus.png")), tr("Add template..."));
 	new_button->setPopupMode(QToolButton::InstantPopup);
 	new_button->setMenu(new_button_menu);
 	
-	delete_button = newToolButton(QIcon(QString::fromLatin1(":/images/minus.png")), tr("Remove"));
+	delete_button = createToolButton(QIcon(QString::fromLatin1(":/images/minus.png")), tr("Remove"));
 	
 	auto* add_remove_layout = new SegmentedButtonLayout();
 	add_remove_layout->addWidget(new_button);
 	add_remove_layout->addWidget(delete_button);
 	
-	move_up_button = newToolButton(QIcon(QString::fromLatin1(":/images/arrow-up.png")), tr("Move Up"));
+	move_up_button = createToolButton(QIcon(QString::fromLatin1(":/images/arrow-up.png")), tr("Move Up"));
 	move_up_button->setAutoRepeat(true);
-	move_down_button = newToolButton(QIcon(QString::fromLatin1(":/images/arrow-down.png")), tr("Move Down"));
+	move_down_button = createToolButton(QIcon(QString::fromLatin1(":/images/arrow-down.png")), tr("Move Down"));
 	move_down_button->setAutoRepeat(true);
 	
 	auto* up_down_layout = new SegmentedButtonLayout();
@@ -274,10 +269,10 @@ TemplateListWidget::TemplateListWidget(Map& map, MapView& main_view, MapEditorCo
 	
 	move_by_hand_action = new QAction(QIcon(QString::fromLatin1(":/images/move.png")), tr("Move by hand"), this);
 	move_by_hand_action->setCheckable(true);
-	move_by_hand_button = newToolButton(move_by_hand_action->icon(), move_by_hand_action->text());
+	move_by_hand_button = createToolButton(move_by_hand_action->icon(), move_by_hand_action->text());
 	move_by_hand_button->setDefaultAction(move_by_hand_action);
 	move_by_hand_button->setVisible(!mobile_mode);
-	adjust_button = newToolButton(QIcon(QString::fromLatin1(":/images/georeferencing.png")), tr("Adjust..."));
+	adjust_button = createToolButton(QIcon(QString::fromLatin1(":/images/georeferencing.png")), tr("Adjust..."));
 	adjust_button->setCheckable(true);
 	adjust_button->setVisible(!mobile_mode);
 	
@@ -295,7 +290,7 @@ TemplateListWidget::TemplateListWidget(Map& map, MapView& main_view, MapEditorCo
 	vectorize_action = nullptr;
 #endif /* WITH_COVE */
 
-	edit_button = newToolButton(QIcon(QString::fromLatin1(":/images/settings.png")),
+	edit_button = createToolButton(QIcon(QString::fromLatin1(":/images/settings.png")),
 	                            ::OpenOrienteering::MapEditorController::tr("&Edit").remove(QLatin1Char('&')));
 	edit_button->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
 	edit_button->setPopupMode(QToolButton::InstantPopup);
@@ -326,7 +321,7 @@ TemplateListWidget::TemplateListWidget(Map& map, MapView& main_view, MapEditorCo
 	
 	if (!mobile_mode)
 	{
-		auto help_button = newToolButton(QIcon(QString::fromLatin1(":/images/help.png")), tr("Help"));
+		auto help_button = createToolButton(QIcon(QString::fromLatin1(":/images/help.png")), tr("Help"));
 		help_button->setAutoRaise(true);
 		all_buttons_layout->addWidget(help_button);
 		connect(help_button, &QAbstractButton::clicked, this, &TemplateListWidget::showHelp);
@@ -499,7 +494,7 @@ void TemplateListWidget::updateButtons()
 		else if (current_row >= 0)
 		{
 			// map row
-			is_georeferenced = map.getGeoreferencing().isValid() && !map.getGeoreferencing().isLocal();
+			is_georeferenced = map.getGeoreferencing().getState() == Georeferencing::Geospatial;
 		}
 		
 		edit_button->setEnabled(edit_enabled);
@@ -840,6 +835,8 @@ void TemplateListWidget::positionClicked(bool checked)
 		controller.addFloatingDockWidget(dock_widget);
 		dock_widget->show();
 		dock_widget->raise();
+		if (dock_widget->isFloating())
+			dock_widget->activateWindow();
 		connect(&controller, &MapEditorController::destroyed, dock_widget, &TemplateAdjustDockWidget::close);
 		connect(this, &TemplateListWidget::currentRowChanged, dock_widget, &TemplateAdjustDockWidget::close);
 		connect(this, &TemplateListWidget::closePositionDockWidget, dock_widget, &TemplateAdjustDockWidget::close);
