@@ -1,10 +1,19 @@
+/****************************************************************************
+**
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
+**
+****************************************************************************/
 /**
+ * Copyright 2015 Kai Pastor
+ *
  * This file is part of OpenOrienteering.
  *
  * This is a modified version of a file from the Qt Toolkit.
  * You can redistribute it and/or modify it under the terms of
  * the GNU General Public License, version 3, as published by
- * the Free Software Foundation.
+ * the Free Software Foundation, or any later version approved
+ * by the KDE Free Qt Foundation
  *
  * OpenOrienteering is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,21 +22,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with OpenOrienteering.  If not, see <http://www.gnu.org/licenses/>
- *
- * Changes:
- * 2015-10-18 Kai Pastor <dg0yt@darc.de>
- * - Adjustment of legal information
- * - Modifications required for separate compilation:
- *   - Renaming of selected files, classes, members and macros
- *   - Adjustment of include statements
- *   - Removal of Q_XXX_EXPORT
  */
-/****************************************************************************
-**
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
-**
-****************************************************************************/
 
 #ifndef QFONTSUBSET_P_H
 #define QFONTSUBSET_P_H
@@ -43,7 +38,8 @@
 // We mean it.
 //
 
-#include <private/qfontengine_p.h>
+#include <QtGui/private/qtguiglobal_p.h>
+#include "private/qfontengine_p.h"
 
 QT_BEGIN_NAMESPACE
 
@@ -77,7 +73,7 @@ public:
     const int object_id;
     bool noEmbed;
     QFontEngine *fontEngine;
-    QList<int> glyph_indices;
+    QVector<int> glyph_indices;
     mutable int downloaded_glyphs;
     mutable bool standard_font;
     int nGlyphs() const { return glyph_indices.size(); }
