@@ -1,19 +1,10 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-****************************************************************************/
 /**
- * Copyright 2015 Kai Pastor
- *
  * This file is part of OpenOrienteering.
  *
  * This is a modified version of a file from the Qt Toolkit.
  * You can redistribute it and/or modify it under the terms of
  * the GNU General Public License, version 3, as published by
- * the Free Software Foundation, or any later version approved
- * by the KDE Free Qt Foundation
+ * the Free Software Foundation.
  *
  * OpenOrienteering is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,7 +13,21 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with OpenOrienteering.  If not, see <http://www.gnu.org/licenses/>
+ *
+ * Changes:
+ * 2015-10-18 Kai Pastor <dg0yt@darc.de>
+ * - Adjustment of legal information
+ * - Modifications required for separate compilation:
+ *   - Renaming of selected files, classes, members and macros
+ *   - Adjustment of include statements
+ *   - Removal of Q_XXX_EXPORT
  */
+/****************************************************************************
+**
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
+**
+****************************************************************************/
 
 #include "qfontsubset_p.h"
 #include <qdebug.h>
@@ -36,8 +41,6 @@
 
 QT_BEGIN_NAMESPACE
 
-#ifndef QT_NO_PDF
-
 // This map is used for symbol fonts to get the correct glyph names for the latin range
 static const unsigned short symbol_map[0x100] = {
     0x0000, 0x0001, 0x0002, 0x0003, 0x0004, 0x0005, 0x0006, 0x0007,
@@ -79,7 +82,7 @@ static const unsigned short symbol_map[0x100] = {
 
 // ---------------------------- PS/PDF helper methods -----------------------------------
 
-
+#ifndef QT_NO_PDF
 
 QByteArray QFontSubset::glyphName(unsigned short unicode, bool symbol)
 {
@@ -125,7 +128,7 @@ QByteArray QFontSubset::widthArray() const
 
     QByteArray width;
     AdvancedPdf::ByteStream s(&width);
-    const qreal scale = 1000.0/emSquare.toInt();
+    QFixed scale = QFixed(1000)/emSquare;
 
     QFixed defWidth = widths[0];
     //qDebug("defWidth=%d, scale=%f", defWidth.toInt(), scale.toReal());
@@ -134,7 +137,7 @@ QByteArray QFontSubset::widthArray() const
             defWidth = 0;
     }
     if (defWidth > 0) {
-        s << "/DW " << qRound(defWidth.toInt() * scale);
+        s << "/DW " << (defWidth*scale).toInt();
     } else {
         s << "/W [";
         for (int g = 0; g < nGlyphs();) {
@@ -163,11 +166,11 @@ QByteArray QFontSubset::widthArray() const
             if (endnonlinear > start) {
                 s << start << '[';
                 for (int i = start; i < endnonlinear; ++i)
-                    s << qRound(widths[i].toInt() * scale);
+                    s << (widths[i]*scale).toInt();
                 s << "]\n";
             }
             if (startLinear)
-                s << startLinear << g - 1 << qRound(widths[startLinear].toInt() * scale) << '\n';
+                s << startLinear << g - 1 << (widths[startLinear]*scale).toInt() << '\n';
         }
         s << "]\n";
     }
@@ -345,7 +348,6 @@ struct qttf_head_table {
     quint16 macStyle;
     qint16 indexToLocFormat;
 };
-Q_DECLARE_TYPEINFO(qttf_head_table, Q_PRIMITIVE_TYPE);
 
 
 struct qttf_hhea_table {
@@ -358,7 +360,6 @@ struct qttf_hhea_table {
     qint16 xMaxExtent;
     quint16 numberOfHMetrics;
 };
-Q_DECLARE_TYPEINFO(qttf_hhea_table, Q_PRIMITIVE_TYPE);
 
 
 struct qttf_maxp_table {
@@ -370,7 +371,6 @@ struct qttf_maxp_table {
     quint16 maxComponentElements;
     quint16 maxComponentDepth;
 };
-Q_DECLARE_TYPEINFO(qttf_maxp_table, Q_PRIMITIVE_TYPE);
 
 struct qttf_name_table {
     QString copyright;
@@ -378,7 +378,6 @@ struct qttf_name_table {
     QString subfamily;
     QString postscript_name;
 };
-Q_DECLARE_TYPEINFO(qttf_name_table, Q_MOVABLE_TYPE);
 
 
 static QTtfTable generateHead(const qttf_head_table &head);
@@ -410,9 +409,9 @@ Q_DECLARE_TYPEINFO(QTtfGlyph, Q_MOVABLE_TYPE);
 
 static QTtfGlyph generateGlyph(int index, const QPainterPath &path, qreal advance, qreal lsb, qreal ppem);
 // generates glyf, loca and hmtx
-static QVector<QTtfTable> generateGlyphTables(qttf_font_tables &tables, const QVector<QTtfGlyph> &_glyphs);
+static QList<QTtfTable> generateGlyphTables(qttf_font_tables &tables, const QList<QTtfGlyph> &_glyphs);
 
-static QByteArray bindFont(const QVector<QTtfTable>& _tables);
+static QByteArray bindFont(const QList<QTtfTable>& _tables);
 
 
 static quint32 checksum(const QByteArray &table)
@@ -606,14 +605,12 @@ struct QTtfNameRecord {
     quint16 nameId;
     QString value;
 };
-Q_DECLARE_TYPEINFO(QTtfNameRecord, Q_MOVABLE_TYPE);
 
-static QTtfTable generateName(const QVector<QTtfNameRecord> &name);
+static QTtfTable generateName(const QList<QTtfNameRecord> &name);
 
 static QTtfTable generateName(const qttf_name_table &name)
 {
-    QVector<QTtfNameRecord> list;
-    list.reserve(5);
+    QList<QTtfNameRecord> list;
     QTtfNameRecord rec;
     rec.nameId = 0;
     rec.value = name.copyright;
@@ -637,7 +634,7 @@ static QTtfTable generateName(const qttf_name_table &name)
 }
 
 // ####### should probably generate Macintosh/Roman name entries as well
-static QTtfTable generateName(const QVector<QTtfNameRecord> &name)
+static QTtfTable generateName(const QList<QTtfNameRecord> &name)
 {
     const int char_size = 2;
 
@@ -708,7 +705,7 @@ struct TTF_POINT {
 };
 Q_DECLARE_TYPEINFO(TTF_POINT, Q_PRIMITIVE_TYPE);
 
-static void convertPath(const QPainterPath &path, QVector<TTF_POINT> *points, QVector<int> *endPoints, qreal ppem)
+static void convertPath(const QPainterPath &path, QList<TTF_POINT> *points, QList<int> *endPoints, qreal ppem)
 {
     int numElements = path.elementCount();
     for (int i = 0; i < numElements - 1; ++i) {
@@ -729,7 +726,7 @@ static void convertPath(const QPainterPath &path, QVector<TTF_POINT> *points, QV
                     points->takeLast();
                 endPoints->append(points->size() - 1);
             }
-            Q_FALLTHROUGH();
+            // fall through
         case QPainterPath::LineToElement:
             p.flags = OnCurve;
             break;
@@ -787,7 +784,7 @@ static void convertPath(const QPainterPath &path, QVector<TTF_POINT> *points, QV
                     base -= 3;
                 } else {
                     // need to split
-//                     qDebug("  -> splitting");
+//                     qDebug() << "  -> splitting";
                     qint16 a, b, c, d;
                     base[6].x = base[3].x;
                     c = base[1].x;
@@ -830,7 +827,7 @@ static void convertPath(const QPainterPath &path, QVector<TTF_POINT> *points, QV
     endPoints->append(points->size() - 1);
 }
 
-static void getBounds(const QVector<TTF_POINT> &points, qint16 *xmin, qint16 *xmax, qint16 *ymin, qint16 *ymax)
+static void getBounds(const QList<TTF_POINT> &points, qint16 *xmin, qint16 *xmax, qint16 *ymin, qint16 *ymax)
 {
     *xmin = points.at(0).x;
     *xmax = *xmin;
@@ -845,10 +842,10 @@ static void getBounds(const QVector<TTF_POINT> &points, qint16 *xmin, qint16 *xm
     }
 }
 
-static int convertToRelative(QVector<TTF_POINT> *points)
+static int convertToRelative(QList<TTF_POINT> *points)
 {
     // convert points to relative and setup flags
-//     qDebug("relative points:");
+//     qDebug() << "relative points:";
     qint16 prev_x = 0;
     qint16 prev_y = 0;
     int point_array_size = 0;
@@ -898,7 +895,7 @@ static int convertToRelative(QVector<TTF_POINT> *points)
     return point_array_size;
 }
 
-static void getGlyphData(QTtfGlyph *glyph, const QVector<TTF_POINT> &points, const QVector<int> &endPoints, int point_array_size)
+static void getGlyphData(QTtfGlyph *glyph, const QList<TTF_POINT> &points, const QList<int> &endPoints, int point_array_size)
 {
     const int max_size = 5*sizeof(qint16) // header
                          + endPoints.size()*sizeof(quint16) // end points of contours
@@ -948,14 +945,14 @@ static void getGlyphData(QTtfGlyph *glyph, const QVector<TTF_POINT> &points, con
 
 static QTtfGlyph generateGlyph(int index, const QPainterPath &path, qreal advance, qreal lsb, qreal ppem)
 {
-    QVector<TTF_POINT> points;
-    QVector<int> endPoints;
+    QList<TTF_POINT> points;
+    QList<int> endPoints;
     QTtfGlyph glyph;
     glyph.index = index;
     glyph.advanceWidth = qRound(advance * 2048. / ppem);
     glyph.lsb = qRound(lsb * 2048. / ppem);
 
-    if (path.isEmpty()) {
+    if (!path.elementCount()) {
         //qDebug("glyph %d is empty", index);
         lsb = 0;
         glyph.xMin = glyph.xMax = glyph.yMin = glyph.yMax = 0;
@@ -969,7 +966,7 @@ static QTtfGlyph generateGlyph(int index, const QPainterPath &path, qreal advanc
 //     qDebug() << "number of contours=" << endPoints.size();
 //     for (int i = 0; i < points.size(); ++i)
 //         qDebug() << "  point[" << i << "] = " << QPoint(points.at(i).x, points.at(i).y) << " flags=" << points.at(i).flags;
-//     qDebug("endPoints:");
+//     qDebug() << "endPoints:";
 //     for (int i = 0; i < endPoints.size(); ++i)
 //         qDebug() << endPoints.at(i);
 
@@ -984,10 +981,10 @@ static bool operator <(const QTtfGlyph &g1, const QTtfGlyph &g2)
     return g1.index < g2.index;
 }
 
-static QVector<QTtfTable> generateGlyphTables(qttf_font_tables &tables, const QVector<QTtfGlyph> &_glyphs)
+static QList<QTtfTable> generateGlyphTables(qttf_font_tables &tables, const QList<QTtfGlyph> &_glyphs)
 {
     const int max_size_small = 65536*2;
-    QVector<QTtfGlyph> glyphs = _glyphs;
+    QList<QTtfGlyph> glyphs = _glyphs;
     std::sort(glyphs.begin(), glyphs.end());
 
     Q_ASSERT(tables.maxp.numGlyphs == glyphs.at(glyphs.size()-1).index + 1);
@@ -1050,8 +1047,7 @@ static QVector<QTtfTable> generateGlyphTables(qttf_font_tables &tables, const QV
     Q_ASSERT(loca.data.size() == ls.offset());
     Q_ASSERT(hmtx.data.size() == hs.offset());
 
-    QVector<QTtfTable> list;
-    list.reserve(3);
+    QList<QTtfTable> list;
     list.append(glyf);
     list.append(loca);
     list.append(hmtx);
@@ -1063,9 +1059,9 @@ static bool operator <(const QTtfTable &t1, const QTtfTable &t2)
     return t1.tag < t2.tag;
 }
 
-static QByteArray bindFont(const QVector<QTtfTable>& _tables)
+static QByteArray bindFont(const QList<QTtfTable>& _tables)
 {
-    QVector<QTtfTable> tables = _tables;
+    QList<QTtfTable> tables = _tables;
 
     std::sort(tables.begin(), tables.end());
 
@@ -1134,7 +1130,7 @@ static QByteArray bindFont(const QVector<QTtfTable>& _tables)
 
     // calculate the fonts checksum and qToBigEndian into 'head's checksum_adjust
     quint32 checksum_adjust = 0xB1B0AFBA - checksum(font);
-    qToBigEndian(checksum_adjust, font.data() + head_offset + 8);
+    qToBigEndian(checksum_adjust, (uchar *)font.data() + head_offset + 8);
 
     return font;
 }
@@ -1156,6 +1152,7 @@ QByteArray QFontSubset::toTruetype() const
 
     qreal ppem = fontEngine->fontDef.pixelSize;
 #define TO_TTF(x) qRound(x * 2048. / ppem)
+    QList<QTtfGlyph> glyphs;
 
     QFontEngine::Properties properties = fontEngine->properties();
     // initialize some stuff needed in createWidthArray
@@ -1190,13 +1187,12 @@ QByteArray QFontSubset::toTruetype() const
     font.maxp.maxCompositeContours = 0;
     font.maxp.maxComponentElements = 0;
     font.maxp.maxComponentDepth = 0;
-    const int numGlyphs = nGlyphs();
-    font.maxp.numGlyphs = numGlyphs;
-    QVector<QTtfGlyph> glyphs;
-    glyphs.reserve(numGlyphs);
+    font.maxp.numGlyphs = nGlyphs();
+
+
 
     uint sumAdvances = 0;
-    for (int i = 0; i < numGlyphs; ++i) {
+    for (int i = 0; i < nGlyphs(); ++i) {
         glyph_t g = glyph_indices.at(i);
         QPainterPath path;
         glyph_metrics_t metric;
@@ -1227,7 +1223,7 @@ QByteArray QFontSubset::toTruetype() const
     }
 
 
-    QVector<QTtfTable> tables = generateGlyphTables(font, glyphs);
+    QList<QTtfTable> tables = generateGlyphTables(font, glyphs);
     tables.append(generateHead(font.head));
     tables.append(generateHhea(font.hhea));
     tables.append(generateMaxp(font.maxp));
