@@ -25,6 +25,7 @@
 
 #include <QtGlobal>
 #include <QByteArray>
+#include <QDialog>
 #include <QPaintDevice>
 #include <QPainter>
 #include <QPoint>
@@ -43,6 +44,7 @@
 #include "core/renderables/renderable.h"
 #include "fileformats/file_format_registry.h"
 #include "fileformats/file_import_export.h"
+#include "gui/georeferencing_dialog.h"
 #include "gui/util_gui.h"
 #include "util/transformation.h"
 #include "util/util.h"
@@ -160,7 +162,6 @@ bool TemplateMap::loadTemplateFileImpl()
 			is_georeferenced = false;
 			transform = transformForOcd();
 			updateTransformationMatrices();
-			setTemplateAreaDirty();
 			setProperty(ocdTransformProperty(), false);
 		}
 		else if (is_georeferenced)
@@ -188,6 +189,10 @@ bool TemplateMap::loadTemplateFileImpl()
 			updateTransformationMatrices();
 			block_georeferencing = false;
 		}
+		else
+		{
+			block_georeferencing = false;
+		}
 	}
 	else if (importer)
 	{
@@ -201,12 +206,30 @@ bool TemplateMap::loadTemplateFileImpl()
 	return new_template_valid;
 }
 
-bool TemplateMap::postLoadSetup(QWidget* /* dialog_parent */, bool& out_center_in_view)
+bool TemplateMap::postLoadSetup(QWidget* dialog_parent, bool& out_center_in_view)
 {
+	if (map->getGeoreferencing().getState() != Georeferencing::Geospatial
+	    && templateMap()->getGeoreferencing().getState() == Georeferencing::Geospatial)
+	{
+		Q_ASSERT(!is_georeferenced);
+		GeoreferencingDialog dialog(dialog_parent, map, &templateMap()->getGeoreferencing());
+		if (dialog.exec() == QDialog::Accepted)
+		{
+			QTransform q_transform;
+			if (!calculateTransformation(q_transform))
+			{
+				setErrorString(tr("Failed to transform the coordinates."));
+				return false;
+			}
+			transform = TemplateTransform::fromQTransform(q_transform);
+			updateTransformationMatrices();
+		}
+	}
 	auto const is_unconfigured = [](auto const& georef) {
-		return georef.isLocal() && georef.toProjectedCoords(MapCoordF{}) == QPointF{};
+		return georef.getState() != Georeferencing::Geospatial && georef.toProjectedCoords(MapCoordF{}) == QPointF{};
 	};
-	out_center_in_view = is_unconfigured(templateMap()->getGeoreferencing());
+	out_center_in_view = is_unconfigured(templateMap()->getGeoreferencing())
+	                     || is_unconfigured(map->getGeoreferencing());
 	return true;
 }
 
@@ -451,11 +474,9 @@ bool TemplateMap::georeferencedStateSupported() const
 		return success;
 	};
 	return !block_georeferencing
-	       && map->getGeoreferencing().isValid()
-	       && !map->getGeoreferencing().isLocal()
+	       && map->getGeoreferencing().getState() == Georeferencing::Geospatial
 	       && templateMap()
-	       && templateMap()->getGeoreferencing().isValid()
-	       && !templateMap()->getGeoreferencing().isLocal()
+	       && templateMap()->getGeoreferencing().getState() == Georeferencing::Geospatial
 	       && test_transform(templateMap()->getGeoreferencing(), map->getGeoreferencing());
 }
 
