@@ -1,5 +1,6 @@
 /*
  *    Copyright 2012, 2013 Thomas Schöps
+ *    Copyright 2020 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -47,6 +48,9 @@ public:
 	bool event(QEvent* event) override;
 	void closeEvent(QCloseEvent* event) override;
 	
+signals:
+	void closed();
+	
 public slots:
 	void templateChanged(int index, const OpenOrienteering::Template* temp);
 	void templateDeleted(int index, const OpenOrienteering::Template* temp);
