@@ -24,6 +24,7 @@
 
 #include <QtGlobal>
 #include <QObject>
+#include <QString>
 
 #include "core/map_coord.h"
 #include "tools/tool.h"
@@ -50,15 +51,15 @@ public:
 	void init() override;
 	const QCursor& getCursor() const override;
 	
-	bool mousePressEvent(QMouseEvent* event, MapCoordF map_coord, MapWidget* widget) override;
-	bool mouseMoveEvent(QMouseEvent* event, MapCoordF map_coord, MapWidget* widget) override;
-	bool mouseReleaseEvent(QMouseEvent* event, MapCoordF map_coord, MapWidget* widget) override;
+	bool mousePressEvent(QMouseEvent* event, const MapCoordF& map_coord, MapWidget* widget) override;
+	bool mouseMoveEvent(QMouseEvent* event, const MapCoordF& map_coord, MapWidget* widget) override;
+	bool mouseReleaseEvent(QMouseEvent* event, const MapCoordF& map_coord, MapWidget* widget) override;
 	
 public slots:
-	void templateDeleted(int index, const Template* temp);
+	void templateDeleted(int index, const OpenOrienteering::Template* temp);
 	
 private:
-	void updateDragging(MapCoordF mouse_pos_map);
+	void updateDragging(const MapCoordF& mouse_pos_map);
 	
 	Template* templ;
 	bool dragging = false;
