@@ -23,11 +23,13 @@
 #define OPENORIENTEERING_SCALE_TOOL_H
 
 #include <QObject>
+#include <QString>
 
 #include "core/map_coord.h"
 #include "tools/tool_base.h"
 
 class QAction;
+class QKeyEvent;
 class QPainter;
 class QRectF;
 
@@ -57,6 +59,9 @@ protected:
 	void dragMove() override;
 	void dragFinish() override;
 	
+	bool keyPressEvent(QKeyEvent* event) override;
+	bool keyReleaseEvent(QKeyEvent* event) override;
+
 	void drawImpl(QPainter* painter, MapWidget* widget) override;
 	
 	int updateDirtyRectImpl(QRectF& rect) override;
@@ -65,6 +70,7 @@ protected:
 	MapCoordF scaling_center;
 	double reference_length = 0;
 	double scaling_factor   = 1;
+	bool using_scaling_center = true;
 };
 
 
