@@ -21,10 +21,13 @@
 
 #include "tool_base.h"
 
+#include <algorithm>
+#include <cstdlib>  // IWYU pragma: keep
 #include <iterator>
 #include <type_traits>
 
 #include <QtGlobal>
+#include <QCoreApplication>  // IWYU pragma: keep
 #include <QMouseEvent>
 #include <QTimer>
 #include <QEvent>
@@ -41,6 +44,11 @@
 #include "undo/object_undo.h"
 
 
+#ifdef __clang_analyzer__
+#define singleShot(A, B, C) singleShot(A, B, #C) // NOLINT 
+#endif
+
+
 namespace OpenOrienteering {
 
 // ### MapEditorToolBase::EditedItem ###
@@ -152,7 +160,7 @@ const QCursor& MapEditorToolBase::getCursor() const
 
 
 
-void MapEditorToolBase::mousePositionEvent(QMouseEvent* event, MapCoordF map_coord, MapWidget* widget)
+void MapEditorToolBase::mousePositionEvent(QMouseEvent* event, const MapCoordF& map_coord, MapWidget* widget)
 {
 	active_modifiers = event->modifiers();
 	cur_pos = event->pos();
@@ -178,7 +186,7 @@ void MapEditorToolBase::mousePositionEvent(QMouseEvent* event, MapCoordF map_coo
 }
 
 
-bool MapEditorToolBase::mousePressEvent(QMouseEvent* event, MapCoordF map_coord, MapWidget* widget)
+bool MapEditorToolBase::mousePressEvent(QMouseEvent* event, const MapCoordF& map_coord, MapWidget* widget)
 {
 	mousePositionEvent(event, map_coord, widget);
 	
@@ -198,7 +206,7 @@ bool MapEditorToolBase::mousePressEvent(QMouseEvent* event, MapCoordF map_coord,
 	}
 }
 
-bool MapEditorToolBase::mouseMoveEvent(QMouseEvent* event, MapCoordF map_coord, MapWidget* widget)
+bool MapEditorToolBase::mouseMoveEvent(QMouseEvent* event, const MapCoordF& map_coord, MapWidget* widget)
 {
 	mousePositionEvent(event, map_coord, widget);
 	
@@ -221,7 +229,7 @@ bool MapEditorToolBase::mouseMoveEvent(QMouseEvent* event, MapCoordF map_coord,
 	}
 }
 
-bool MapEditorToolBase::mouseReleaseEvent(QMouseEvent* event, MapCoordF map_coord, MapWidget* widget)
+bool MapEditorToolBase::mouseReleaseEvent(QMouseEvent* event, const MapCoordF& map_coord, MapWidget* widget)
 {
 	mousePositionEvent(event, map_coord, widget);
 	
@@ -254,7 +262,7 @@ bool MapEditorToolBase::keyPressEvent(QKeyEvent* event)
 #if defined(Q_OS_MACOS)
 	// FIXME: On Mac, QKeyEvent::modifiers() seems to return the keyboard 
 	// modifier flags that existed immediately before the event occurred.
-	// This is in contradiction to the documenation for QKeyEvent::modifiers(),
+	// This is in contradiction to the documentation for QKeyEvent::modifiers(),
 	// but the documented behaviour of (parent) QInputEvent::modifiers().
 	// Qt5 doc says QKeyEvent::modifiers() "cannot always be trusted." ...
 	switch (event->key())
@@ -284,7 +292,7 @@ bool MapEditorToolBase::keyReleaseEvent(QKeyEvent* event)
 #if defined(Q_OS_MACOS)
 	// FIXME: On Mac, QKeyEvent::modifiers() seems to return the keyboard 
 	// modifier flags that existed immediately before the event occurred.
-	// This is in contradiction to the documenation for QKeyEvent::modifiers(),
+	// This is in contradiction to the documentation for QKeyEvent::modifiers(),
 	// but the documented behaviour of (parent) QInputEvent::modifiers().
 	// Qt5 doc says QKeyEvent::modifiers() "cannot always be trusted." ...
 	switch (event->key())
@@ -474,7 +482,7 @@ void MapEditorToolBase::updatePreviewObjectsAsynchronously()
 	
 	if (!preview_update_triggered)
 	{
-		QTimer::singleShot(10, this, SLOT(updatePreviewObjectsSlot()));  // clazy:exclude=old-style-connect
+		QTimer::singleShot(10, this, &MapEditorToolBase::updatePreviewObjectsSlot);
 		preview_update_triggered = true;
 	}
 }
@@ -676,13 +684,13 @@ void MapEditorToolBase::generateNextSimulatedEvent()
 			QMouseEvent release(QEvent::MouseButtonRelease, next_pos, Qt::LeftButton, Qt::LeftButton, active_modifiers);
 			qApp->sendEvent(mapWidget(), &release);
 		}
-		// fall through
+		Q_FALLTHROUGH();
 	default:
 		simulation_state = 0;
 	}
 	// Continue until Ctrl key is released and the current sequence was completed.
 	if (simulation_state != 0 || active_modifiers.testFlag(Qt::ControlModifier))
-		QTimer::singleShot(100, this, SLOT(generateNextSimulatedEvent()));
+		QTimer::singleShot(100, this, &MapEditorToolBase::generateNextSimulatedEvent);
 	++simulation_state;
 }
 
