@@ -1,5 +1,5 @@
 /*
- *    Copyright 2013 Kai Pastor
+ *    Copyright 2013-2019 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -19,7 +19,6 @@
 
 #include "overriding_shortcut.h"
 
-#include <QtGlobal>
 #include <QEvent>
 #include <QKeyEvent>
 #include <QShortcutEvent>
@@ -31,42 +30,44 @@ namespace OpenOrienteering {
 // ### OverridingShortcut ###
 
 OverridingShortcut::OverridingShortcut(QWidget* parent)
- : QShortcut(parent)
-{
-	Q_ASSERT(parent);
-	parent->window()->installEventFilter(this);
-	timer.start();
-}
+ : OverridingShortcut(QKeySequence{}, parent, nullptr, nullptr, Qt::WindowShortcut)
+{}
 
 OverridingShortcut::OverridingShortcut(const QKeySequence& key, QWidget* parent, const char* member, const char* ambiguousMember, Qt::ShortcutContext context)
  : QShortcut(key, parent, member, ambiguousMember, context)
+ , parent_or_self(parent)
 {
-	Q_ASSERT(parent);
-	parent->window()->installEventFilter(this);
-	timer.start();
+	if (!parent_or_self)
+		parent_or_self = this;
+	parent_or_self->installEventFilter(this);
+	updateEventFilters();
 }
 
 
-OverridingShortcut::~OverridingShortcut() = default;
-
-
-
-bool OverridingShortcut::eventFilter(QObject* /*watched*/, QEvent* event)
+OverridingShortcut::~OverridingShortcut()
 {
-	if (event->type() == QEvent::ShortcutOverride && key().count() == 1)
+	parent_or_self->removeEventFilter(this);
+	if (window_)
+		window_->removeEventFilter(this);
+}
+
+
+
+bool OverridingShortcut::eventFilter(QObject* watched, QEvent* event)
+{
+	if (event->type() == QEvent::ParentChange
+	    && (watched == parent_or_self || watched == window_) )
 	{
-		QKeyEvent* key_event = static_cast<QKeyEvent*>(event);
+		updateEventFilters();
+	}
+	else if (event->type() == QEvent::ShortcutOverride
+	         && isEnabled() && key().count() == 1)
+	{
+		auto* key_event = static_cast<QKeyEvent*>(event);
 		if ((key_event->key() | int(key_event->modifiers())) == key()[0])
 		{
-			if (timer.elapsed() < 50) // milliseconds
-			{
-				event->accept();
-				return true;
-			}
-			
 			QShortcutEvent se(key(), id());
 			event->setAccepted(QShortcut::event(&se));
-			timer.restart();
 			return event->isAccepted();
 		}
 	}
@@ -75,4 +76,27 @@ bool OverridingShortcut::eventFilter(QObject* /*watched*/, QEvent* event)
 }
 
 
+void OverridingShortcut::updateEventFilters()
+{
+	QObject* new_parent_or_self = parent() ? parent() : this; 
+	if (parent_or_self != new_parent_or_self)
+	{
+		parent_or_self->removeEventFilter(this);
+		parent_or_self = new_parent_or_self;
+		parent_or_self->installEventFilter(this);
+	}
+	
+	QWidget* parent_widget = qobject_cast<QWidget*>(parent());
+	QWidget* new_window = parent_widget ? parent_widget->window() : nullptr;
+	if (window_ != new_window)
+	{
+		if (window_)
+			window_->removeEventFilter(this);
+		window_ = new_window;
+		if (window_)
+			window_->installEventFilter(this);
+	}
+}
+
+
 }  // namespace OpenOrienteering
