@@ -1,5 +1,5 @@
 /*
- *    Copyright 2012-2020 Kai Pastor
+ *    Copyright 2012-2021 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -34,7 +34,7 @@
 #  include <proj.h>
 #endif
 
-#ifdef MAPPER_USE_GDAL
+#ifdef MAPPER_TEST_GDAL
 #  include <gdal.h>
 #  include <ogr_api.h>
 #  include <ogr_srs_api.h>
@@ -117,14 +117,22 @@ namespace
 void GeoreferencingTest::initTestCase()
 {
 	XMLFileFormat::active_version = 6;
+	
+#ifndef ACCEPT_USE_OF_DEPRECATED_PROJ_API_H
+	auto info = proj_info();
+	QVERIFY(info.major == PROJ_VERSION_MAJOR);
+	QVERIFY(info.minor == PROJ_VERSION_MINOR);
+#endif
+	
+#ifdef MAPPER_TEST_GDAL
+	QVERIFY(GDALCheckVersion(GDAL_VERSION_MAJOR, GDAL_VERSION_MINOR, "GeoreferencingTest") == TRUE);
+#endif
 }
 
 
 void GeoreferencingTest::testEmptyProjectedCRS()
 {
 	Georeferencing new_georef;
-	QVERIFY(new_georef.isValid());
-	QVERIFY(new_georef.isLocal());
 	QCOMPARE(new_georef.getState(), Georeferencing::Local);
 	QCOMPARE(new_georef.getScaleDenominator(), 1000u);
 	QCOMPARE(new_georef.getCombinedScaleFactor(), 1.0);
@@ -137,6 +145,27 @@ void GeoreferencingTest::testEmptyProjectedCRS()
 	QCOMPARE(new_georef.getProjectedRefPoint(), QPointF(0.0, 0.0));
 }
 
+void GeoreferencingTest::testStateChanges()
+{
+	Georeferencing georef;
+	QCOMPARE(georef.getState(), Georeferencing::Local);
+	// From local to broken
+	georef.setProjectedCRS(QStringLiteral("Broken"), QStringLiteral("+init=epsg:BROKEN"));
+	QCOMPARE(georef.getState(), Georeferencing::BrokenGeospatial);
+	// From broken to geospatial
+	georef.setProjectedCRS(QStringLiteral("UTM 32"), utm32_spec);
+	QCOMPARE(georef.getState(), Georeferencing::Geospatial);
+	// From geospatial to broken
+	georef.setProjectedCRS(QStringLiteral("Broken"), QStringLiteral("+init=epsg:BROKEN"));
+	QCOMPARE(georef.getState(), Georeferencing::BrokenGeospatial);
+	// From broken to broken
+	georef.setProjectedCRS(QStringLiteral("Broken"), {});
+	QCOMPARE(georef.getState(), Georeferencing::BrokenGeospatial);
+	// From broken to local
+	georef.setLocalState();
+	QCOMPARE(georef.getState(), Georeferencing::Local);
+}
+
 void GeoreferencingTest::testGridScaleFactor_data()
 {
 	QTest::addColumn<QString>("spec");
@@ -160,11 +189,11 @@ void GeoreferencingTest::testGridScaleFactor()
 	
 	Georeferencing georef;
 	georef.setProjectedCRS(QString::fromLatin1(QTest::currentDataTag()), spec);
-	QVERIFY2(georef.isValid(), georef.getErrorText().toLatin1());
+	QCOMPARE(georef.getState(), Georeferencing::Geospatial);
 	
 	auto const latlon = LatLon{lat, lon};
 	georef.setGeographicRefPoint(latlon);
-	QVERIFY2(georef.isValid(), georef.getErrorText().toLatin1());
+	QCOMPARE(georef.getState(), Georeferencing::Geospatial);
 	
 	// Verify scale_x
 	auto const east = georef.getProjectedRefPoint() + QPointF{500.0, 0.0};
@@ -231,7 +260,7 @@ void GeoreferencingTest::testGridScaleFactor()
 	
 	// See that the auxiliary scale factor is preserved when the CRS changes.
 	georef.setProjectedCRS(QString::fromLatin1(QTest::currentDataTag()), utm32_spec);
-	QVERIFY2(georef.isValid(), georef.getErrorText().toLatin1());
+	QCOMPARE(georef.getState(), Georeferencing::Geospatial);
 	QCOMPARE(georef.getAuxiliaryScaleFactor(), elevation_scale_factor);
 	map_distance = QLineF{georef.toMapCoordF(sw), georef.toMapCoordF(ne)}.length();
 	ground_distance = map_distance * georef.getScaleDenominator() / 1000;
@@ -248,7 +277,7 @@ void GeoreferencingTest::testGridScaleFactor()
 	georef.setAuxiliaryScaleFactor(0.95);
 	auto const expected_combined = georef.getCombinedScaleFactor();
 	auto const map_coord = georef.toMapCoordF(sw);
-	georef.setState(Georeferencing::Local);
+	georef.setLocalState();
 	QVERIFY(georef.getProjectedCRSSpec().isEmpty());
 	// This call to setDeclination must not have side-effects.
 	georef.setDeclination(georef.getDeclination());
@@ -304,6 +333,14 @@ void GeoreferencingTest::testCRS_data()
 	        << utm32_spec
 	        << utm32_spec
 	        << false;
+	QTest::newRow("latlong basic")
+	        << QStringLiteral("EPSG:4326")
+	        << QStringLiteral("+proj=latlong +datum=WGS84")
+	        << true;
+	QTest::newRow("longlat +no_defs")
+	        << QStringLiteral("urn:ogc:def:crs:OGC:1.3:CRS84")
+	        << QStringLiteral("+proj=longlat +datum=WGS84 +no_defs")
+	        << true;
 }
 
 void GeoreferencingTest::testCRS()
@@ -353,7 +390,7 @@ void GeoreferencingTest::testCRSTemplates()
 	
 	Georeferencing georef;
 	georef.setProjectedCRS(QStringLiteral("EPSG"), epsg_template->specificationTemplate().arg(QStringLiteral("5514")), { QStringLiteral("5514") });
-	QVERIFY(georef.isValid());
+	QCOMPARE(georef.getState(), Georeferencing::Geospatial);
 	QCOMPARE(georef.getProjectedCoordinatesName(), QStringLiteral("EPSG 5514 coordinates"));
 }
 
@@ -391,6 +428,12 @@ void GeoreferencingTest::testProjection_data()
 	auto epsg27700_spec = QStringLiteral("+init=epsg:27700");
 	QTest::newRow("EPSG 27700 NY 06071 11978") << epsg27700_spec << 306071.0  << 511978.0 << 54.494403  << -3.4517026;
 	QTest::newRow("EPSG 27700 Lake District")  << epsg27700_spec << 306074.66 << 511974.0 << 54.4943673 << -3.4516448;
+	
+	// latlong vs. longlat
+	QTest::newRow("latlong basic") << QStringLiteral("+proj=latlong +datum=WGS84")             << -6.0 << 51.0 << 51.0 << -6.0;
+	QTest::newRow("latlong +no_defs") << QStringLiteral("+proj=latlong +datum=WGS84 +no_defs") << 16.0 << 49.0 << 49.0 << 16.0;
+	QTest::newRow("longlat basic") << QStringLiteral("+proj=longlat +datum=WGS84")             << -6.0  << 51.0 << 51.0 << -6.0;
+	QTest::newRow("longlat +no_defs") << QStringLiteral("+proj=longlat +datum=WGS84 +no_defs") << 16.0  << 49.0 << 49.0 << 16.0;
 }
 
 
@@ -430,7 +473,7 @@ void GeoreferencingTest::testProjection()
 	if (std::fabs(lat_lon.longitude() - longitude) > (max_angl_error * std::cos(qDegreesToRadians(latitude))))
 		QCOMPARE(QString::number(lat_lon.longitude(), 'f'), QString::number(longitude, 'f'));
 	
-#ifdef MAPPER_USE_GDAL
+#ifdef MAPPER_TEST_GDAL
 	// Cf. OgrFileExport::setupGeoreferencing
 	auto* map_srs = OSRNewSpatialReference(nullptr);
 	OSRSetProjCS(map_srs, "Projected map SRS");
@@ -470,7 +513,7 @@ void GeoreferencingTest::testProjection()
 	
 	OSRDestroySpatialReference(geo_srs);
 	OSRDestroySpatialReference(map_srs);
-#endif  // MAPPPER_USE_GDAL
+#endif  // MAPPER_TEST_GDAL
 }
 
 
