@@ -38,6 +38,7 @@
 #include <QIODevice>
 #include <QLatin1Char>
 #include <QLatin1String>
+#include <QMetaObject>
 #include <QPagedPaintDevice>
 #include <QPrinter>
 #include <QRectF>
@@ -727,8 +728,10 @@ void saveIfDifferent(QFile& file, QByteArray& new_data, const QByteArray& existi
 
 void SymbolSetTool::initTestCase()
 {
+	// Use distinct QSettings
 	QCoreApplication::setOrganizationName(QString::fromLatin1("OpenOrienteering.org"));
-	QCoreApplication::setApplicationName(QString::fromLatin1("SymbolSetTool"));
+	QCoreApplication::setApplicationName(QString::fromLatin1(metaObject()->className()));
+	QVERIFY2(QDir::home().exists(), "The home dir must be writable in order to use QSettings.");
 	
 	doStaticInitializations();
 	
