@@ -23,29 +23,36 @@
 #include <memory>
 #include <vector>
 
+#include <Qt>
 #include <QtGlobal>
 #include <QtMath>
 #include <QtTest>
 #include <QBuffer>
 #include <QByteArray>
+#include <QColor>
 #include <QCoreApplication>
 #include <QDir>
 #include <QFile>
 #include <QFileDevice>
 #include <QFileInfo>
+#include <QImageWriter>
 #include <QIODevice>
 #include <QLineF>
+#include <QList>
 #include <QMetaObject>
 #include <QObject>
-#include <QPainter>
-#include <QPicture>
 #include <QPointF>
 #include <QRectF>
 #include <QSignalSpy>  // IWYU pragma: keep
 #include <QString>
 #include <QStringList>
+#include <QTemporaryDir>
 #include <QTransform>
 
+#ifdef ACCEPT_USE_OF_DEPRECATED_PROJ_API_H
+#  include <proj_api.h>
+#endif
+
 #include "test_config.h"
 
 #include "global.h"
@@ -54,32 +61,33 @@
 #include "core/map.h"
 #include "core/map_coord.h"
 #include "core/map_view.h"
+#include "fileformats/file_format.h"
+#include "fileformats/file_format_registry.h"
+#include "fileformats/file_import_export.h"
 #include "fileformats/xml_file_format_p.h"
 #include "gdal/ogr_template.h"
 #include "gdal/gdal_manager.h"
 #include "templates/template.h"
+#include "templates/template_image.h"
 #include "templates/template_table_model.h"
 #include "templates/template_track.h"
 #include "templates/world_file.h"
 
+#ifdef MAPPER_USE_GDAL
+#  include "gdal/gdal_file.h"
+#endif
+
 using namespace OpenOrienteering;
 
 namespace
 {
 
-QPointF center(const TemplateTrack* temp)
-{
-	QPicture picture;
-	QPainter painter(&picture);
-	temp->drawTracks(&painter, false);
-	painter.end();
-	return QRectF(picture.boundingRect()).center();
-}
-
 QPointF center(const Template* temp)
 {
+	// TemplateTrack intentionally doesn't provide a tight extent
+	// but the bounding box is fine.
 	if (auto* template_track = qobject_cast<const TemplateTrack*>(temp))
-		return center(template_track);
+		return template_track->calculateTemplateBoundingBox().center();
 	return temp->templateToMap(temp->getTemplateExtent().center());
 }
 
@@ -95,8 +103,11 @@ Q_OBJECT
 private slots:
 	void initTestCase()
 	{
+		// Use distinct QSettings
 		QCoreApplication::setOrganizationName(QString::fromLatin1("OpenOrienteering.org"));
 		QCoreApplication::setApplicationName(QString::fromLatin1(metaObject()->className()));
+		QVERIFY2(QDir::home().exists(), "The home dir must be writable in order to use QSettings.");
+		
 		Q_INIT_RESOURCE(resources);
 		doStaticInitializations();
 		// Static map initializations
@@ -104,6 +115,57 @@ private slots:
 		QDir::addSearchPath(QStringLiteral("testdata"), QDir(QString::fromUtf8(MAPPER_TEST_SOURCE_DIR)).absoluteFilePath(QStringLiteral("data")));
 	}
 	
+#ifdef MAPPER_USE_GDAL
+	// These tests are related to GDAL/OGR template support, but also for OgrFileFormat.
+	void gdalUtilTest()
+	{
+		QString const test_file = QStringLiteral("testdata:templates/vsi-test.kmz");
+		auto const test_file_info = QFileInfo(test_file);
+		QVERIFY(test_file_info.exists());
+		
+		auto const abs_path_utf8 = test_file_info.absoluteFilePath().toUtf8();
+		QVERIFY(GdalFile::exists(abs_path_utf8));
+		QVERIFY(!GdalFile::exists(abs_path_utf8 + "_xy"));
+		
+		auto const vsizip = QByteArray("/vsizip/" + abs_path_utf8);
+		QVERIFY(GdalFile::exists(vsizip + "/doc.kml"));
+		QVERIFY(!GdalFile::exists(vsizip + "/doc.kml_xy"));
+		QVERIFY(GdalFile::exists(vsizip + "/files"));
+		QVERIFY(!GdalFile::exists(vsizip + "/files_xy"));
+		
+		QVERIFY(GdalFile::exists(vsizip + "/files/1.jpg"));
+		QVERIFY(!GdalFile::exists(vsizip + "/files/1.jpg_xy"));
+		
+		QVERIFY(GdalFile::isRelative("files/1.jpg"));
+		QVERIFY(GdalFile::isRelative("../doc.kml"));
+		
+		QVERIFY(GdalFile::isDir(vsizip + "/files"));
+		QVERIFY(!GdalFile::isDir(vsizip + "/doc.kml"));
+		QVERIFY(!GdalFile::isDir(vsizip + "/doc.kml_xy"));
+		
+		auto resolved_path = GdalFile::tryToFindRelativeTemplateFile("files/1.jpg", vsizip);
+		QVERIFY(!resolved_path.isEmpty());
+		QVERIFY(resolved_path.startsWith("/vsizip/"));
+		QVERIFY(resolved_path.endsWith("/1.jpg"));
+		QVERIFY(GdalFile::exists(resolved_path));
+		
+		resolved_path = GdalFile::tryToFindRelativeTemplateFile("files/1.jpg", vsizip + "/doc.kml");
+		QVERIFY(!resolved_path.isEmpty());
+		QVERIFY(resolved_path.startsWith("/vsizip/"));
+		QVERIFY(resolved_path.endsWith("/1.jpg"));
+		QVERIFY(GdalFile::exists(resolved_path));
+		
+		resolved_path = GdalFile::tryToFindRelativeTemplateFile("../doc.kml", vsizip + "/files/1.jpg");
+		QVERIFY(!resolved_path.isEmpty());
+		QVERIFY(resolved_path.startsWith("/vsizip/"));
+		QVERIFY(resolved_path.endsWith("/doc.kml"));
+		QVERIFY(GdalFile::exists(resolved_path));
+		
+		resolved_path = GdalFile::tryToFindRelativeTemplateFile("../doc.kml_xy", vsizip + "/files/1.jpg");
+		QVERIFY(resolved_path.isEmpty());
+	}
+#endif
+	
 	void worldFilePathTest()
 	{
 		QCOMPARE(WorldFile::pathForImage(QStringLiteral("dir.ext/file-noext")), QStringLiteral("dir.ext/file-noext.wld"));
@@ -166,7 +228,7 @@ private slots:
 		QVERIFY(map.loadFrom(QStringLiteral("testdata:templates/world-file.xmap"), &view));
 		
 		const auto& georef = map.getGeoreferencing();
-		QVERIFY(georef.isValid());
+		QCOMPARE(georef.getState(), Georeferencing::Geospatial);
 		
 		QCOMPARE(map.getNumTemplates(), 1);
 		auto temp = map.getTemplate(0);
@@ -241,6 +303,53 @@ private slots:
 		QCOMPARE(out_buffer.buffer(), original_data);
 	}
 	
+	void templateImageDrawableTest()
+	{
+		QVERIFY(!QImageWriter::supportedImageFormats().isEmpty());
+		
+		Map map;
+		XMLFileImporter importer{ QStringLiteral("testdata:templates/world-file.xmap"), &map, nullptr };
+		QVERIFY(importer.doImport());
+		
+		QCOMPARE(map.getNumTemplates(), 1);
+		auto* temp = map.getTemplate(0);
+		QCOMPARE(temp->getTemplateType(), "TemplateImage");
+		QCOMPARE(temp->getTemplateFilename(), QStringLiteral("world-file.png"));
+		QCOMPARE(temp->getTemplateState(), Template::Unloaded);
+		QVERIFY(!temp->canBeDrawnOnto());
+		
+		QVERIFY(temp->loadTemplateFile());
+		QCOMPARE(temp->getTemplateState(), Template::Loaded);
+		if (!QImageWriter::supportedImageFormats().contains("png"))
+			QEXPECT_FAIL("", "No PNG support in this build of Qt", Abort);
+		QVERIFY(temp->canBeDrawnOnto());
+		QVERIFY(!temp->hasUnsavedChanges());
+		
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)  // for QTemporaryDir::filePath()
+		QTemporaryDir tmp_dir;
+		QVERIFY(tmp_dir.isValid());
+		temp->setTemplatePath(tmp_dir.filePath(temp->getTemplateFilename()));
+		QVERIFY(temp->canBeDrawnOnto());
+		QVERIFY(!temp->hasUnsavedChanges());
+		
+		auto const box = temp->calculateTemplateBoundingBox();
+		MapCoordF map_coords[] = { MapCoordF(box.topLeft()), MapCoordF(box.bottomRight()) };
+		temp->drawOntoTemplate(map_coords, 2, QColor(Qt::red), box.width()+box.height(), box, {});
+		QVERIFY(temp->hasUnsavedChanges());
+		
+#if !defined(MAPPER_BIG_ENDIAN)
+		auto format = FileFormats.findFormatForFilename(QStringLiteral("some.ocd"), &FileFormat::supportsFileSave);
+		QVERIFY(bool(format));
+		auto exporter = format->makeExporter(QString{}, &map, nullptr);
+		QVERIFY(bool(exporter));
+		QBuffer buffer;
+		exporter->setDevice(&buffer);
+		QVERIFY(exporter->doExport());
+		QVERIFY(!temp->hasUnsavedChanges());
+#endif  // !defined(MAPPER_BIG_ENDIAN)
+#endif  // Qt 5.9
+	}
+	
 	void geoTiffTemplateTest()
 	{
 		Map map;
@@ -248,7 +357,7 @@ private slots:
 		QVERIFY(map.loadFrom(QStringLiteral("testdata:templates/geotiff.xmap"), &view));
 		
 		const auto& georef = map.getGeoreferencing();
-		QVERIFY(georef.isValid());
+		QCOMPARE(georef.getState(), Georeferencing::Geospatial);
 		
 		QCOMPARE(map.getNumTemplates(), 1);
 		auto temp = map.getTemplate(0);
@@ -271,6 +380,35 @@ private slots:
 #endif
 	}
 	
+#ifdef MAPPER_USE_GDAL
+	void geoTiffSRSTest()
+	{
+		auto file_info = QFileInfo(QStringLiteral("testdata:templates/epsg-27700.tiff"));
+		QVERIFY(file_info.exists());
+		
+		Map map;
+		auto temp = Template::templateForPath(file_info.absoluteFilePath(), &map);
+		QCOMPARE(temp->getTemplateType(), "GdalTemplate");
+		QVERIFY(temp->loadTemplateFile());
+		
+		auto gdal_template = qobject_cast<TemplateImage*>(temp.get());
+		QVERIFY(gdal_template);
+		auto options = gdal_template->availableGeoreferencing();
+		QVERIFY(!options.template_file.crs_spec.isEmpty());
+		
+		Georeferencing georef;
+		georef.setProjectedCRS({}, options.template_file.crs_spec);
+		bool ok;
+		auto projected = georef.toProjectedCoords(LatLon(54.558203, -3.393209), &ok);
+		QVERIFY(ok);
+		auto expected = QPointF{310000, 519000};
+		if (QLineF(projected, expected).length() > 0.5)
+			QCOMPARE(projected, expected);
+		else
+			QVERIFY2(true, "SRS from GeoTIFF is okay");
+	}
+#endif
+	
 	void templateTrackTest_data()
 	{
 		QTest::addColumn<QString>("map_file");
@@ -280,6 +418,10 @@ private slots:
 		QTest::newRow("TemplateTrack non-georef")     << QStringLiteral("testdata:templates/template-track.xmap") << 1;
 		QTest::newRow("TemplateTrack OGR georef")     << QStringLiteral("testdata:templates/template-track.xmap") << 2;
 		QTest::newRow("TemplateTrack OGR non-georef") << QStringLiteral("testdata:templates/template-track.xmap") << 3;
+		QTest::newRow("TemplateTrack NAD83")          << QStringLiteral("testdata:templates/template-track-NA.xmap") << 0;
+		QTest::newRow("OgrTemplate NAD83")            << QStringLiteral("testdata:templates/template-track-NA.xmap") << 1;
+		QTest::newRow("TemplateTrack from v0.8.4")    << QStringLiteral("testdata:templates/template-track-NA-084.xmap") << 0;
+		QTest::newRow("TemplateTrack from v0.9.3")    << QStringLiteral("testdata:templates/template-track-NA-093-PROJ.xmap") << 0;
 	}
 	
 	void templateTrackTest()
@@ -302,8 +444,15 @@ private slots:
 		QVERIFY(map.getTemplate(template_index)->loadTemplateFile());
 		QCOMPARE(temp->getTemplateState(), Template::Loaded);
 
+#if !defined(ACCEPT_USE_OF_DEPRECATED_PROJ_API_H) || PJ_VERSION >= 600
+		QEXPECT_FAIL("TemplateTrack from v0.8.4", "Unsupported WGS 84 -> NAD 83 transformation", Continue);
+#else
+		QEXPECT_FAIL("TemplateTrack NAD83", "Unsupported WGS 84 -> NAD 83 transformation", Continue);
+		QEXPECT_FAIL("OgrTemplate NAD83", "Unsupported WGS 84 -> NAD 83 transformation", Continue);
+		QEXPECT_FAIL("TemplateTrack from v0.9.3", "Unsupported WGS 84 -> NAD 83 transformation", Continue);
+#endif
 		auto const expected_center = map.calculateExtent().center();
-		if (QLineF(center(temp), expected_center).length() > 0.5)
+		if (QLineF(center(temp), expected_center).length() > 0.125) // 50 cm
 			QCOMPARE(center(temp), expected_center);
 		else
 			QVERIFY2(true, "Centers do match");
@@ -321,6 +470,10 @@ private slots:
 		QTest::newRow("TemplateTrack OGR non-georef") << QStringLiteral("testdata:templates/template-track.xmap") << 3;
 		QTest::newRow("OgrTemplate basic")            << QStringLiteral("testdata:templates/ogr-template.xmap")   << 0;
 		QTest::newRow("OgrTemplate compatibility")    << QStringLiteral("testdata:templates/ogr-template.xmap")   << 1;
+		QTest::newRow("TemplateTrack NAD83")          << QStringLiteral("testdata:templates/template-track-NA.xmap") << 0;
+		QTest::newRow("OgrTemplate NAD83")            << QStringLiteral("testdata:templates/template-track-NA.xmap") << 1;
+		QTest::newRow("TemplateTrack from v0.8.4")    << QStringLiteral("testdata:templates/template-track-NA-084.xmap") << 0;
+		QTest::newRow("OGRTemplate from v0.9.3")      << QStringLiteral("testdata:templates/template-track-NA-093-GDAL.xmap") << 0;
 	}
 	
 	void ogrTemplateTest()
@@ -341,8 +494,10 @@ private slots:
 		QVERIFY(map.getTemplate(template_index)->loadTemplateFile());
 		QCOMPARE(temp->getTemplateState(), Template::Loaded);
 
+		QEXPECT_FAIL("TemplateTrack NAD83", "Unsupported WGS 84 -> NAD 83 transformation", Continue);
+		QEXPECT_FAIL("OgrTemplate NAD83", "Unsupported WGS 84 -> NAD 83 transformation", Continue);
 		auto const expected_center = map.calculateExtent().center();
-		if (QLineF(center(temp), expected_center).length() > 0.5)
+		if (QLineF(center(temp), expected_center).length() > 0.25) // 1 m
 			QCOMPARE(center(temp), expected_center);
 		else
 			QVERIFY2(true, "Centers do match");
@@ -361,6 +516,66 @@ private slots:
 		QCOMPARE(qRound(latlon.latitude()), 50);
 		QCOMPARE(qRound(latlon.longitude()), 8);
 	}
+	
+	void templateTypesConsistentTest_data()
+	{
+		QTest::addColumn<QString>("map_file");
+		QTest::addColumn<int>("template_index");
+
+		QTest::newRow("TemplateTrack georef")     << QStringLiteral("testdata:templates/template-track.xmap") << 0;
+		QTest::newRow("OgrTemplate georef")       << QStringLiteral("testdata:templates/template-track.xmap") << 2;
+		QTest::newRow("TemplateTrack NAD83")      << QStringLiteral("testdata:templates/template-track-NA.xmap") << 0;
+		QTest::newRow("OgrTemplate NAD83")        << QStringLiteral("testdata:templates/template-track-NA.xmap") << 1;
+	}
+	
+	void templateTypesConsistentTest()
+	{
+		QFETCH(QString, map_file);
+		QFETCH(int, template_index);
+		
+		GdalManager().setFormatEnabled(GdalManager::GPX, false);
+		QPointF template_track_center;
+		{
+			Map map;
+			MapView view{ &map };
+			QVERIFY(map.loadFrom(map_file, &view));
+
+			QVERIFY(map.getNumTemplates() > template_index);
+			auto const* temp = map.getTemplate(template_index);
+			QCOMPARE(temp->getTemplateType(), "TemplateTrack");
+			QCOMPARE(temp->getTemplateState(), Template::Unloaded);
+			QVERIFY(map.getTemplate(template_index)->loadTemplateFile());
+			QCOMPARE(temp->getTemplateState(), Template::Loaded);
+
+			template_track_center = center(temp);
+		}
+
+		GdalManager().setFormatEnabled(GdalManager::GPX, true);
+		QPointF ogr_template_center;
+		{
+			Map map;
+			MapView view{ &map };
+			QVERIFY(map.loadFrom(map_file, &view));
+
+			QVERIFY(map.getNumTemplates() > template_index);
+			auto const* temp = map.getTemplate(template_index);
+			QCOMPARE(temp->getTemplateType(), "OgrTemplate");
+			QCOMPARE(temp->getTemplateState(), Template::Unloaded);
+			QVERIFY(map.getTemplate(template_index)->loadTemplateFile());
+			QCOMPARE(temp->getTemplateState(), Template::Loaded);
+
+			ogr_template_center = center(temp);
+		}
+		
+#if !defined(ACCEPT_USE_OF_DEPRECATED_PROJ_API_H) || PJ_VERSION >= 600
+		QEXPECT_FAIL("TemplateTrack NAD83", "Unsupported WGS 84 -> NAD 83 transformation", Continue);
+		QEXPECT_FAIL("OgrTemplate NAD83", "Unsupported WGS 84 -> NAD 83 transformation", Continue);
+#endif
+		if (QLineF(ogr_template_center, template_track_center).length() > 0.1) // 40 cm
+			QCOMPARE(ogr_template_center, template_track_center);
+		else
+			QVERIFY2(true, "Centers do match");
+	}
 #endif
 	
 	void templateRotationTest_data()
@@ -392,7 +607,7 @@ private slots:
 		QVERIFY(map.loadFrom(map_file, &view));
 		
 		auto const& georef = map.getGeoreferencing();
-		QVERIFY(georef.isValid());
+		QCOMPARE(georef.getState(), Georeferencing::Geospatial);
 		QVERIFY(std::abs(georef.getGrivation()) >= 0.01);
 		
 		QVERIFY(map.getNumTemplates() > template_index);
